@@ -49,6 +49,7 @@
 
 package com.openexchange.usm.api.cache;
 
+import java.io.Serializable;
 import java.util.Set;
 import com.openexchange.usm.api.session.CompleteSessionID;
 
@@ -74,7 +75,7 @@ public interface SyncStateCache {
      * @param data sync state data
      * @return true if data was stored, false if not
      */
-    boolean put(CompleteSessionID session, String objectID, long timestamp, byte[] data);
+    boolean put(CompleteSessionID session, String objectID, long timestamp, Serializable[][] data);
 
     /**
      * Return a previously stored sync state from the cache. If no sync state is found for (SessionID, objectID, timestamp), return null.
@@ -84,7 +85,7 @@ public interface SyncStateCache {
      * @param timestamp
      * @return sync state for (SessionID, objectID, timestamp), or null if not found
      */
-    byte[] get(CompleteSessionID session, String objectID, long timestamp);
+    Serializable[][] get(CompleteSessionID session, String objectID, long timestamp);
 
     /**
      * Remove the specified (obsolete) sync state from the cache (if found). It is no longer used by the sync system.
