@@ -51,6 +51,7 @@ package com.openexchange.usm.api.contenttypes;
 
 import java.util.BitSet;
 import com.openexchange.usm.api.exceptions.USMException;
+import com.openexchange.usm.api.session.DataObjectFilter;
 import com.openexchange.usm.api.session.Folder;
 import com.openexchange.usm.api.session.Session;
 
@@ -85,9 +86,10 @@ public interface FolderContentTypeTransferHandler extends ContentTypeTransferHan
      * 
      * @param object
      * @param limit
+     * @param filter
      * @throws USMException
      */
-    OXFolderContent readFolderContent(Folder folder, int limit) throws USMException;
+    OXFolderContent readFolderContent(Folder folder, int limit, DataObjectFilter filter) throws USMException;
 
     /**
      * Defines more specific return type than generic interface
