@@ -127,4 +127,9 @@ public interface DatabaseAccess {
      * @throws DatabaseAccessException if the array could not be generated/retrieved
      */
     int[] getContextsInSameSchema(int contextId) throws DatabaseAccessException;
+    
+    
+    boolean supportsOnDuplicateKeyUpdateStatement();
+    
+    boolean supportsInsertIgnoreStatement();
 }
