@@ -49,7 +49,6 @@
 package com.openexchange.usm.api.datatypes;
 
 import java.io.Serializable;
-import java.util.Arrays;
 import java.util.LinkedHashMap;
 import java.util.UUID;
 import org.json.JSONArray;
@@ -81,6 +80,8 @@ public class PIMAttachment implements Serializable {
 	private static final String CREATION_DATE = "creation_date";
 
 	private static final String CREATED_BY = "created_by";
+	
+	private static final String TEMPID = "tempid";
 
 	public static final String ID = "id";
 
@@ -121,7 +122,8 @@ public class PIMAttachment implements Serializable {
 	private final transient String _mimeType;
 	private final transient boolean _rtfFlag;
 	private final transient long _fileSize;
-	private transient byte[] _data;
+	private final transient byte[] _data;
+	private final transient String _tempid;
 
 	public PIMAttachment(int oxId, UUID uuid) {
 		_oxId = oxId;
@@ -133,6 +135,7 @@ public class PIMAttachment implements Serializable {
 		_rtfFlag = false;
 		_fileSize = 0L;
 		_data = null;
+		_tempid = null;
 	}
 
 	public PIMAttachment(PIMAttachment source, UUID uuid) {
@@ -145,6 +148,7 @@ public class PIMAttachment implements Serializable {
 	    _rtfFlag = source._rtfFlag;
 	    _fileSize = source._fileSize;
 	    _data = source._data;
+        _tempid = source._tempid;
 	}
 	
 	public PIMAttachment(UUID uuid, String fileName, String mimeType, long fileSize, String createdBy,
@@ -157,6 +161,7 @@ public class PIMAttachment implements Serializable {
 		_creationDate = creationDate;
 		_rtfFlag = rtfFlag;
 		_data = data;
+        _tempid = null;
 	}
 
 	public PIMAttachment(UUID uuid, JSONObject jsonObject, byte[] data) {
@@ -168,10 +173,11 @@ public class PIMAttachment implements Serializable {
 		_creationDate = jsonObject.optLong(CREATION_DATE, 0L);
 		_rtfFlag = jsonObject.optBoolean(RTF_FLAG, false);
 		_oxId = jsonObject.optInt(ID);
+        _tempid = jsonObject.optString(TEMPID, null);
 		_data = data;
 	}
 
-	public PIMAttachment(UUID uuid, JSONArray jsonArray, byte[] data) {
+	public PIMAttachment(UUID uuid, JSONArray jsonArray) {
 		_uuid = uuid;
 		//indexes in the JSONArray are expected as in the FIELDS map
 		_oxId = jsonArray.optInt(0);
@@ -181,8 +187,8 @@ public class PIMAttachment implements Serializable {
 		_fileSize = jsonArray.optLong(7, 0L);
 		_mimeType = jsonArray.optString(8, null);
 		_rtfFlag = jsonArray.optBoolean(9, false);
-
-		_data = data;
+		_data = null;
+        _tempid = null;
 	}
 
 	/**
@@ -250,10 +256,10 @@ public class PIMAttachment implements Serializable {
 		return _data;
 	}
 
-	public void setData(byte[] data) {
-		_data = data;
+	public String getTempId() {
+	    return _tempid;
 	}
-
+	
 	@Override
 	public boolean equals(Object obj) {
 		if (this == obj)
@@ -277,8 +283,6 @@ public class PIMAttachment implements Serializable {
 			return false;
 		if (_fileSize != other._fileSize)
 			return false;
-		if (!Arrays.equals(_data, other._data))
-			return false;
 		if (!isEqual(_uuid, other._uuid))
 			return false;
 		return true;
@@ -301,8 +305,6 @@ public class PIMAttachment implements Serializable {
 			return false;
 		if (_fileSize != other._fileSize)
 			return false;
-		if (!Arrays.equals(_data, other._data))
-			return false;
 		return true;
 	}
 
@@ -317,15 +319,12 @@ public class PIMAttachment implements Serializable {
 		result = prime * result + ((_mimeType == null) ? 0 : _mimeType.hashCode());
 		result = prime * result + (_rtfFlag ? 1 : 0);
 		result = (int) (prime * result + _fileSize);
-		result = prime * result + ((_data == null) ? 0 : _data.hashCode());
 		result = prime * result + ((_uuid == null) ? 0 : _uuid.hashCode());
 		return result;
 	}
 
     @Override
     public String toString() {
-        if (_data == null)
-            return _fileName + '(' + _uuid + ')';
-        return _fileName + '(' + _uuid + '/' + _data.length + ')';
+        return _fileName + '(' + _uuid + '/' + _oxId + '/' + _fileSize + ')';
     }
 }
