@@ -49,6 +49,7 @@
 
 package com.openexchange.usm.api.datatypes;
 
+import java.io.Serializable;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
@@ -59,7 +60,7 @@ import com.openexchange.usm.api.session.Session;
  * 
  * @author afe
  */
-public class PIMAttachmentsDataType extends AbstractDataType<PIMAttachments> implements DataType<PIMAttachments> {
+public class PIMAttachmentsDataType extends AbstractDataType<PIMAttachments> {
 
     private static final String NAME = "Attachments";
 
@@ -98,4 +99,16 @@ public class PIMAttachmentsDataType extends AbstractDataType<PIMAttachments> imp
         PIMAttachments v = checkValue(source);
         return (v != null && v.isForceModified()) ? new PIMAttachments(v.getTimestamp(), v.getAttachments()) : v;
     }
+
+    @Override
+    public Serializable serialize(Object value) {
+        return (value instanceof PIMAttachments) ? new SerializedPIMAttachments((PIMAttachments) value) : null;
+    }
+
+    @Override
+    public PIMAttachments deserialize(Serializable value) {
+        if (value instanceof SerializedPIMAttachments)
+            return ((SerializedPIMAttachments) value).toPIMAttachments();
+        return super.deserialize(value);
+    }
 }
