@@ -51,7 +51,6 @@ package com.openexchange.usm.api.session;
 import java.io.Serializable;
 import java.util.BitSet;
 import java.util.UUID;
-
 import com.openexchange.usm.api.contenttypes.ContentType;
 import com.openexchange.usm.api.exceptions.DeserializationFailedException;
 
@@ -304,13 +303,23 @@ public interface DataObject extends Serializable {
 	 * equalsWithoutID() returns true if the objects are of the same type, have the same ChangeState, have the
 	 * same session and all fields except the one for the ID have the same original and current content.<br>
 	 * Note that equalsWithoutID() and equals() both ignore the failed flag and the original and current
-	 * timestamps for checking equality.
+	 * timestamps and last_modified fields for checking equality.
 	 * 
 	 * @param other
-	 * @return true if both DataObjects are considered equal, ignoring the ID field
+	 * @return true if both DataObjects are considered equal, ignoring the ID and last_modified field
 	 */
 	boolean equalsWithoutID(DataObject other);
 
+    /**
+     * This method behaves as equals(), but it also takes the last_modified-field into account. This field is normally not used by
+     * protocols, but required to minimize local communication between USM and OX and therefore its current value must be stored in all
+     * SyncStates.
+     * 
+     * @param other
+     * @return true if both DataObjects are considered equal, ignoring no field
+     */
+    boolean equalsWithLastModified(DataObject other);
+
 	/**
 	 * This method stores all current individual field information into an array of Serializable objects.
 	 * Only the current field information will be serialized, no extra information like ContentType, Session,
