@@ -48,6 +48,8 @@
  */
 package com.openexchange.usm.api.session;
 
+import java.io.Serializable;
+
 /**
  * Interface for a filter that can be applied to DataObjects, e.g. to filter out elements
  * that are on the server but the client protocol is not interested in them.
@@ -55,7 +57,7 @@ package com.openexchange.usm.api.session;
  * @author afe
  *
  */
-public interface DataObjectFilter {
+public interface DataObjectFilter extends  Serializable {
 
 	/**
 	 * Called before a sync to allow initialization or resetting of any internal fields the filter may use to compute
