@@ -962,4 +962,9 @@ public interface Session {
      * @param id
      */
     void unlock(String id);
+
+    /**
+     * @return The configured mail folder id separators as stored in the Ajax-config "modules" / "mail" / "separators"
+     */
+    public Map<String, String> getMailFolderIdSeparators();
 }
