@@ -49,7 +49,6 @@
 package com.openexchange.usm.api.session;
 
 import java.util.Map;
-
 import com.openexchange.usm.api.exceptions.USMException;
 
 /**
@@ -109,5 +108,5 @@ public interface SessionManager {
 	Session getSession(String user, String password, String protocol, String device, SessionInitializer initializer,
 			String clientIP, Map<String, String> xHeaders) throws USMException;
 
-	boolean existsSessionInDB(String user, String protocol, String device) throws USMException;
+	boolean existsSessionInDB(String user, String password, String protocol, String device) throws USMException;
 }
