@@ -158,6 +158,27 @@ public class ConfigurationProperties {
      */
     public static final boolean OX_ACCESS_PASS_HOST_HEADER_FROM_CLIENT_DEFAULT = true;
 
+    /**
+     * This property defines a list of OX error codes that will trigger a re-login and re-execution of the request instead of reporting the error to the caller
+     */
+    public static final String OX_ACCESS_RELOGIN_ERROR_CODES_PROPERTY = "com.openexchange.usm.ox.relogin_error_codes";
+
+    /**
+     * Default value for com.openexchange.usm.ox.relogin_error_codes
+     */
+    public static final String OX_ACCESS_RELOGIN_ERROR_CODES_DEFAULT = "SES-0202,SES-0203,SES-0206";
+
+    /**
+     * This property defines how long a synchronization request will wait for exclusive access to the object (specific folder or folder hierarchy) that
+     * it wants to synchronize.
+     */
+    public static final String SYNC_LOCK_TIMEOUT_PROPERTY = "com.openexchange.usm.session.sync.lock.timeout";
+
+    /**
+     * Default value for com.openexchange.usm.session.sync.lock.timeout
+     */
+    public static final int SYNC_LOCK_TIMEOUT_DEFAULT = 10000;
+    
     /**
      * Used by the slow and incremental syncer to limit the number of retries if a concurrent modification is detected while performing a
      * synchronization with a client.
@@ -204,12 +225,11 @@ public class ConfigurationProperties {
      * hierarchy itself (per session/client). If a client connects to the USM with a given sync state, all older states are automatically
      * removed, the new state is computed, stored in the database and sent to the client. As long a client uses an old synckey, new keys
      * keep getting generated, but none deleted. If the limit specified here is reached, the USM deletes the oldest sync state on a client
-     * connect. Based on the value of the property com.openexchange.usm.session.sync.keep_last_sent_state_in_db the USM either deletes the
-     * oldest sync state (false) or the oldest one that's not equal to the one the client just used to sync with (true). Note that the value
-     * of this property imposes an upper limit to the number of sync states stored in the cache and database. If a client behaves as
-     * expected, only 2 states will be stored (the one used by the client to initiate synchronization in case the synchronization result
-     * does not reach the client, and the new generated one that contains the base state for the next synchronization). The lower limit for
-     * this property is 2, since at least 2 sync states are required to account for communication failures.
+     * connect that is not the one the client just used. Note that the value of this property imposes an upper limit to the number of sync
+     * states stored in the cache and database. If a client behaves as expected, only 2 states will be stored (the one used by the client to
+     * initiate synchronization in case the synchronization result does not reach the client, and the new generated one that contains the
+     * base state for the next synchronization). The lower limit for this property is 2, since at least 2 sync states are required to
+     * account for communication failures.
      */
     public static final String SYNC_MAX_STATES_IN_DB_PROPERTY = "com.openexchange.usm.session.sync.max_states_in_db";
 
@@ -218,18 +238,6 @@ public class ConfigurationProperties {
      */
     public static final int SYNC_MAX_STATES_IN_DB_DEFAULT = 5;
 
-    /**
-     * If this property is set to true, the USM ensures that the sync state corresponding to the last sync key that was used by a client
-     * stays in the cache and database. If set to false, the USM always deletes the oldest sync state if the limit of allowed sync states is
-     * reached for a folder.
-     */
-    public static final String SYNC_KEEP_LAST_SENT_STATE_IN_DB_PROPERTY = "com.openexchange.usm.session.sync.keep_last_sent_state_in_db";
-
-    /**
-     * Default value(true) for com.openexchange.usm.session.sync.keep_last_sent_state_in_db.
-     */
-    public static final boolean SYNC_KEEP_LAST_SENT_STATE_IN_DB_DEFAULT = true;
-
     /**
      * This property defines how long server data should be cached after a sync has been completed (i.e. all changes have been reported to
      * the client). A value of 0 specifies "no caching". If a new sync is executed within the time frame and the data is still available in
@@ -255,10 +263,6 @@ public class ConfigurationProperties {
      */
     public static final int SYNC_CACHE_TIME_LIMIT_INCOMPLETE_DEFAULT = 1200000; // 20 minutes
 
-    public static final String USM_FORCE_NEW_SYNC_KEY_ON_EMPTY_SYNC = "com.openexchange.usm.force_new_sync_key_on_empty_sync";
-
-    public static final boolean USM_FORCE_NEW_SYNC_KEY_ON_EMPTY_SYNC_DEFAULT = false;
-
     public static final String OBJECTS_IN_FOLDER_SYNC_LIMIT_PROPERTY = "com.openexchange.usm.max_objects_per_folder";
 
     public static final int OBJECTS_IN_FOLDER_SYNC_LIMIT_DEFAULT = 65535;
@@ -348,10 +352,6 @@ public class ConfigurationProperties {
 
     public static final int JSON_SERVLET_PIM_ATTACHMENT_COUNT_LIMIT_DEFAULT = 5;
 
-    public static final String JSON_SERVLET_FATAL_UUID_ERRORS_PROPERTY = "com.openexchange.usm.json.sync.fatal_uuid_errors";
-
-    public static final boolean JSON_SERVLET_FATAL_UUID_ERRORS_DEFAULT = false;
-
     public static final String JSON_SERVLET_MAX_EMAIL_SIZE_PROPERTY = "com.openexchange.usm.json.max_email_size";
 
     public static final int JSON_SERVLET_MAX_EMAIL_SIZE_DEFAULT = 50 * 1024 * 1024; // 50 MByte
