@@ -138,6 +138,7 @@ public class AppointmentContentTypeTransferHandler extends AbstractTransferHandl
         parameters.put(UtilConstants.START, String.valueOf(session.getStartDate()));
         parameters.put(UtilConstants.END, String.valueOf(session.getEndDate()));
         addObjectsLimitParameters(folder.getSession(), parameters);
+        addShowPrivateParameter(parameters, session);
         DataObject[] result = performActionAndCheckRights(UtilConstants.ACTION_ALL, folder, requestedFields, parameters);
 
         resetRecurrenceTypeBasedFields(result);
@@ -145,8 +146,16 @@ public class AppointmentContentTypeTransferHandler extends AbstractTransferHandl
     }
 
     @Override
-    protected void addExtraTimestampListParameters(Map<String, String> parameters) {
+    protected void addExtraTimestampListParameters(Map<String, String> parameters, Session session) {
         parameters.put(UtilConstants.RECURRENCE_MASTER, Boolean.TRUE.toString());
+        addShowPrivateParameter(parameters, session);
+    }
+    
+    @Override
+    protected void addShowPrivateParameter(Map<String, String> parameters, Session session) {
+        if("JSON".equals(session.getProtocol())) {
+            parameters.put("showPrivate", Boolean.TRUE.toString());
+        }
     }
 
     @Override
@@ -169,7 +178,7 @@ public class AppointmentContentTypeTransferHandler extends AbstractTransferHandl
         parameters.put(UtilConstants.COLUMNS, createColumnsParameter(requestedFields));
         parameters.put(UtilConstants.START, String.valueOf(session.getStartDate()));
         parameters.put(UtilConstants.END, String.valueOf(session.getEndDate()));
-        addExtraTimestampListParameters(parameters);
+        addExtraTimestampListParameters(parameters, session);
         addObjectsLimitParameters(session, parameters);
 
         JSONResult jsonResult = _ajaxAccess.doGet(getOXAjaxAccessPath(), UtilConstants.ACTION_ALL, session, parameters);
@@ -196,6 +205,7 @@ public class AppointmentContentTypeTransferHandler extends AbstractTransferHandl
             parameters.put(UtilConstants.FOLDER, folder);
         parameters.put(UtilConstants.RECURRENCE_MASTER, Boolean.FALSE.toString());
         addObjectsLimitParameters(session, parameters);
+        addShowPrivateParameter(parameters, session);
 
         JSONResult jsonResult = _ajaxAccess.doGet(getOXAjaxAccessPath(), UtilConstants.ACTION_ALL, session, parameters);
         JSONArray jArray = extractArrayResult(jsonResult);
@@ -232,6 +242,7 @@ public class AppointmentContentTypeTransferHandler extends AbstractTransferHandl
         parameters.put(UtilConstants.COLUMNS, createColumnsParameter(requestedFields));
         parameters.put(UtilConstants.FOLDER, seriesObject.getParentFolderID());
         parameters.put(UtilConstants.ID, seriesObject.getID());
+        addShowPrivateParameter(parameters, session);
 
         JSONResult jsonResult = _ajaxAccess.doGet(getOXAjaxAccessPath(), CalendarConstants.GET_CHANGE_EXCEPTIONS_ACTION, session, parameters);
         DataObject[] result = buildResultArray(session, requestedFields, jsonResult);
