@@ -81,6 +81,7 @@ import com.openexchange.usm.api.session.DataObject;
 import com.openexchange.usm.api.session.Session;
 import com.openexchange.usm.api.session.SyncResult;
 import com.openexchange.usm.contenttypes.util.AbstractTransferHandler;
+import com.openexchange.usm.contenttypes.util.OXErrorConstants;
 import com.openexchange.usm.contenttypes.util.USMContentTypesUtilErrorCodes;
 import com.openexchange.usm.contenttypes.util.UtilConstants;
 import com.openexchange.usm.datatypes.contacts.Image;
@@ -133,9 +134,9 @@ public class ContactContentTypeTransferHandler extends AbstractTransferHandler {
 		Map<String, DataObject[]> result = new HashMap<String, DataObject[]>();
 		Map<String, String> parameters = new HashMap<String, String>();
 		parameters.put(UtilConstants.COLUMNS, createColumnsParameter(requestedFields));
-		JSONObject requestBody = new JSONObject();
 
 		for (String to : toList) {
+	        JSONObject requestBody = new JSONObject();
 			try {
 				requestBody.put(ContactConstants.LAST_NAME, to);
 				requestBody.put(ContactConstants.FIRST_NAME, to);
@@ -148,11 +149,21 @@ public class ContactContentTypeTransferHandler extends AbstractTransferHandler {
 
 			JSONResult jResult = _ajaxAccess.doPut(getOXAjaxAccessPath(), ACTION_SEARCH, session, parameters,
 					requestBody);
-			//fill List
-			result.put(to, parseRecipientsResult(jResult, session, requestedFields));
+            if (jResult.getResultType() == JSONResultType.Error && isUnderMinimumSearchCharactersError(jResult.getJSONObject())) {
+                result.put(to, new DataObject[0]);
+            } else {
+                // fill List
+                result.put(to, parseRecipientsResult(jResult, session, requestedFields));
+            }
 		}
 		return result;
 	}
+	
+	private boolean isUnderMinimumSearchCharactersError(JSONObject errorObject) {
+	    int category = errorObject.optInt(UtilConstants.CATEGORY);
+        String code = errorObject.optString(UtilConstants.CODE);
+        return (OXErrorConstants.CATEGORY_WRONG_INPUT == category && OXErrorConstants.CON_1000.equals(code));
+	}
 
 	private DataObject[] parseRecipientsResult(JSONResult jResult, Session session, BitSet requestedFields)
 			throws OXCommunicationException, InternalUSMException {
