@@ -48,12 +48,17 @@
  */
 package com.openexchange.usm.contenttypes.contacts.impl;
 
-import java.util.*;
-
+import java.util.BitSet;
+import java.util.List;
+import java.util.Map;
 import org.osgi.service.component.ComponentContext;
-
-import com.openexchange.usm.api.contenttypes.*;
-import com.openexchange.usm.api.exceptions.*;
+import com.openexchange.usm.api.contenttypes.ContactContentType;
+import com.openexchange.usm.api.contenttypes.ContentType;
+import com.openexchange.usm.api.contenttypes.PictureConversionException;
+import com.openexchange.usm.api.contenttypes.UnsupportedContentOperationException;
+import com.openexchange.usm.api.exceptions.AuthenticationFailedException;
+import com.openexchange.usm.api.exceptions.InternalUSMException;
+import com.openexchange.usm.api.exceptions.OXCommunicationException;
 import com.openexchange.usm.api.session.DataObject;
 import com.openexchange.usm.api.session.Session;
 import com.openexchange.usm.contenttypes.util.AbstractContentTypeService;
