@@ -59,6 +59,7 @@ import com.openexchange.usm.api.datatypes.PIMAttachment;
 import com.openexchange.usm.api.datatypes.PIMAttachments;
 import com.openexchange.usm.api.exceptions.USMException;
 import com.openexchange.usm.api.session.DataObject;
+import com.openexchange.usm.api.session.DataObjectFilter;
 import com.openexchange.usm.api.session.Folder;
 import com.openexchange.usm.api.session.Session;
 import com.openexchange.usm.ox_json.OXJSONAccess;
@@ -91,8 +92,8 @@ public class FolderContentTypeTransferHandlerDelegator implements FolderContentT
         return getTransferHandlerImplementation(folder).readFolderContent(folder);
     }
 
-    public OXFolderContent readFolderContent(Folder folder, int limit) throws USMException {
-        return getTransferHandlerImplementation(folder).readFolderContent(folder, limit);
+    public OXFolderContent readFolderContent(Folder folder, int limit, DataObjectFilter filter) throws USMException {
+        return getTransferHandlerImplementation(folder).readFolderContent(folder, limit, filter);
     }
 
     public Folder[] readFolderContent(Folder folder, BitSet requestedFields) throws USMException {
