@@ -173,7 +173,7 @@ public class FolderContentTypeTransferHandlerImpl extends AbstractTransferHandle
             checkAuthenticationFailed(result.getJSONObject());
             throw new FolderNotFoundException(
                 USMContentTypesFolderErrorCodes.FOLDER_NOT_FOUND,
-                "Folder not found: " + object.getUUID() + '(' + object.getID() + ')');
+                "Folder not found: " + object.getUUID() + '(' + object.getID() + ')', result.getJSONObject());
         }
         checkResult(result, JSONResultType.JSONObject);
         updateDataObjectFromJSONResult(object, requestedFields, result);
