@@ -62,6 +62,7 @@ import com.openexchange.usm.api.contenttypes.UnsupportedContentOperationExceptio
 import com.openexchange.usm.api.exceptions.InternalUSMException;
 import com.openexchange.usm.api.exceptions.USMException;
 import com.openexchange.usm.api.session.DataObject;
+import com.openexchange.usm.api.session.DataObjectFilter;
 import com.openexchange.usm.api.session.Folder;
 import com.openexchange.usm.api.session.Session;
 import com.openexchange.usm.contenttypes.util.AbstractTransferHandler;
@@ -118,7 +119,7 @@ public class GroupsContentTypeTransferHandler extends AbstractTransferHandler {
 	}
 
     @Override
-    public OXFolderContent readFolderContent(Folder folder, int limit) throws USMException {
+    public OXFolderContent readFolderContent(Folder folder, int limit, DataObjectFilter filter) throws USMException {
         return new OXFolderContent(true, readFolderContent(folder, folder.getSession().getFieldFilter(folder.getElementsContentType())));
     }
 
