@@ -109,7 +109,8 @@ public class MailContentTypeImpl extends AbstractContentType implements MailCont
         new ContentTypeField(-14, MailConstants.NESTED_MSGS, new NestedMailDataType(), true),// Each element is a mail object as described
                                                                                              // in this table, except for fields id,
                                                                                              // folder_id and attachment.
-        new ContentTypeField(-16, MailConstants.MAIL_CONTENT_TYPE, STRING), };
+        new ContentTypeField(-16, MailConstants.MAIL_CONTENT_TYPE, STRING),
+        new ContentTypeField(-18, MailConstants.SOURCE, STRING),};
 
     public static ContentTypeField[] getAllFields() {
         return FIELDS;
