@@ -89,6 +89,8 @@ import com.openexchange.usm.util.Toolkit;
 
 public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler {
 
+    private static final String ATTACH_SRC = "attach_src";
+
     private static final String _RECEIVED_DATE_COLUMN = "610";
 
     private static final String DROP_PREFIX = "dropPrefix";
@@ -130,11 +132,14 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
     private final int _idIndex;
 
     private final int _receivedDateIndex;
+    
+    private final int _sourceFieldIndex;
 
     public MailContentTypeTransferHandlerImpl(MailContentType contentType, Log log, OXJSONAccess ajaxAccess) {
         super(contentType, log, ajaxAccess);
         _idIndex = getFieldIndex(MailConstants.FIELD_ID);
         _receivedDateIndex = getFieldIndex(MailConstants.RECEIVED_DATE);
+        _sourceFieldIndex = getFieldIndex(MailConstants.SOURCE);
         _getAllBitSet.set(_idIndex);
         _getAllBitSet.set(_receivedDateIndex);
     }
@@ -386,6 +391,13 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
         Map<String, String> parameters = new HashMap<String, String>();
         parameters.put(UNSEEN, ONE);
         parameters.put(VIEW, RAW);
+        if("EAS".equals(object.getSession().getProtocol())){
+            parameters.put(ATTACH_SRC, ONE);
+            BitSet extendedFields = new BitSet();
+            extendedFields.or(requestedFields);
+            extendedFields.set(_sourceFieldIndex);
+            requestedFields = extendedFields;
+        }
         readDataObject(object, requestedFields, parameters);
     }
 
@@ -740,13 +752,15 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
         // GET /ajax/mailfilter?action=list&flag=vacation&session=4108cc5c4bee4d309e10b013ad280a90 HTTP/1.1\r\n
         // RESULT:
         // {"data":[{"active":true,"id":0,"test":{"id":"true"},"rulename":"Abwesenheit","position":0,"actioncmds":[{"id":"vacation","days":"7","text":"This is a test Out Of Office email.","addresses":["user5@ox-p5.microdoc.com","user5@ox.
+        Vacation vacation = new Vacation();
         Map<String, String> parameters = new HashMap<String, String>();
         parameters.put(FLAG, Vacation.RULE_ID);
         JSONResult jResult = _ajaxAccess.doGet(MAILFILTER_AJAX_PATH, UtilConstants.ACTION_LIST, session, parameters);
         checkResult(jResult, JSONResultType.JSONObject);
         try {
             JSONArray jsonar = jResult.getJSONObject().getJSONArray(UtilConstants.RESULT_DATA);
-            Vacation vacation = new Vacation(jsonar.getJSONObject(0));
+            if(jsonar != null && jsonar.length() > 0)  
+                vacation = new Vacation(jsonar.getJSONObject(0));
             return vacation.toJSONObject();
         } catch (JSONException e) {
             _journal.error(session + " Can not read the vacation rule", e);
@@ -811,7 +825,6 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
                 "Vacation Rule: can not create request Body",
                 e);
         }
-
         return requestBody;
     }
 
