@@ -48,18 +48,28 @@
  */
 package com.openexchange.usm.contenttypes.resources.impl;
 
-import java.util.*;
-
+import java.util.BitSet;
+import java.util.HashMap;
+import java.util.Map;
 import org.apache.commons.logging.Log;
-import org.json.*;
-
-import com.openexchange.usm.api.contenttypes.*;
+import org.json.JSONArray;
+import org.json.JSONException;
+import org.json.JSONObject;
+import com.openexchange.usm.api.contenttypes.ContentType;
+import com.openexchange.usm.api.contenttypes.ContentTypeField;
+import com.openexchange.usm.api.contenttypes.OXFolderContent;
+import com.openexchange.usm.api.contenttypes.UnsupportedContentOperationException;
 import com.openexchange.usm.api.exceptions.InternalUSMException;
 import com.openexchange.usm.api.exceptions.USMException;
-import com.openexchange.usm.api.session.*;
+import com.openexchange.usm.api.session.DataObject;
+import com.openexchange.usm.api.session.DataObjectFilter;
+import com.openexchange.usm.api.session.Folder;
+import com.openexchange.usm.api.session.Session;
 import com.openexchange.usm.contenttypes.util.AbstractTransferHandler;
 import com.openexchange.usm.contenttypes.util.UtilConstants;
-import com.openexchange.usm.ox_json.*;
+import com.openexchange.usm.ox_json.JSONResult;
+import com.openexchange.usm.ox_json.JSONResultType;
+import com.openexchange.usm.ox_json.OXJSONAccess;
 
 public class ResourcesContentTypeTransferHandler extends AbstractTransferHandler {
 
@@ -106,7 +116,7 @@ public class ResourcesContentTypeTransferHandler extends AbstractTransferHandler
 	}
 
     @Override
-    public OXFolderContent readFolderContent(Folder folder, int limit) throws USMException {
+    public OXFolderContent readFolderContent(Folder folder, int limit, DataObjectFilter filter) throws USMException {
         return new OXFolderContent(true, readFolderContent(folder, folder.getSession().getFieldFilter(folder.getElementsContentType())));
     }
 
