@@ -54,6 +54,7 @@ import com.openexchange.usm.api.contenttypes.OXFolderContent;
 import com.openexchange.usm.api.contenttypes.TaskContentType;
 import com.openexchange.usm.api.exceptions.USMException;
 import com.openexchange.usm.api.session.DataObject;
+import com.openexchange.usm.api.session.DataObjectFilter;
 import com.openexchange.usm.api.session.Folder;
 import com.openexchange.usm.contenttypes.util.AbstractTransferHandler;
 import com.openexchange.usm.ox_json.OXJSONAccess;
@@ -75,8 +76,8 @@ public class TaskContentTypeTransferHandlerImpl extends AbstractTransferHandler
 	}
 
     @Override
-    public OXFolderContent readFolderContent(Folder folder, int limit) throws USMException {
-        OXFolderContent result = super.readFolderContent(folder, limit);
+    public OXFolderContent readFolderContent(Folder folder, int limit, DataObjectFilter filter) throws USMException {
+        OXFolderContent result = super.readFolderContent(folder, limit, filter);
         resetRecurrenceTypeBasedFields(result.getObjects());
         return result;
     }
