@@ -743,7 +743,7 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
         String folderTree = object.getSession().getPersistentField(FolderContentType.FOLDER_TREE);
         if (!isFolder) {
             parameters.put(UtilConstants.FOLDER, object.getOriginalParentFolderID());
-        } else if (folderTree != null) {
+        } else if (folderTree != null  && folderTree.length() > 0) {
             parameters.put(UtilConstants.TREE, folderTree);
         }
         parameters.put(UtilConstants.TIMESTAMP, String.valueOf(timestamp));
@@ -755,7 +755,7 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
             if (result.getResultType() == JSONResultType.Error) {
                 if (isFolderNotExistError(result.getJSONObject()))
 					throw new FolderNotFoundException(USMContentTypesUtilErrorCodes.FOLDER_NOT_FOUND,
-                        "Folder not found: " + object.getUUID() + '(' + object.getID() + ')');
+                        "Folder not found: " + object.getUUID() + '(' + object.getID() + ')', result.getJSONObject());
             }
             checkResult(result, JSONResultType.JSONObject);
             JSONObject o = result.getJSONObject();
@@ -846,6 +846,7 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
             parameters.put(UtilConstants.TREE, folderTree);
         }
         addObjectsLimitParameters(folder.getSession(), parameters);
+        addShowPrivateParameter(parameters, folder.getSession());
         JSONResult result = _ajaxAccess.doGet(getOXAjaxAccessPath(), action, folder.getSession(), parameters);
         return getListOfUpdates(folder, requestedFields, result);
     }
@@ -891,7 +892,9 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
 
 	protected void setAppOrTaskConfirmations(DataObject object) throws AuthenticationFailedException,
 			OXCommunicationException {
-        if (object.isFieldModified(CommonCalendarTasksFieldNames.USERS)) {
+        if (!object.isFieldModified(CommonCalendarTasksFieldNames.USERS)) 
+            return;
+            
             int folderOwner = computeFolderOwnerID(object);
             Object[] users = (Object[]) object.getFieldContent(CommonCalendarTasksFieldNames.USERS);
             Object[] usersOld = (Object[]) object.getOriginalFieldContent(CommonCalendarTasksFieldNames.USERS);
@@ -913,7 +916,7 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
                     }
                 }
             }
-        }
+ 
     }
 
     protected abstract String getOXAjaxAccessPath();
@@ -1012,7 +1015,7 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
         Map<String, String> parameters = new HashMap<String, String>();
         parameters.put(UtilConstants.FOLDER, folder.getID());
         parameters.put(UtilConstants.COLUMNS, _COLUMNS_ID_AND_LAST_MODIFIED);
-        addExtraTimestampListParameters(parameters);
+        addExtraTimestampListParameters(parameters, folder.getSession());
         Session session = folder.getSession();
         parameters.put(UtilConstants.START, String.valueOf(session.getStartDate()));
         parameters.put(UtilConstants.END, String.valueOf(session.getEndDate()));
@@ -1032,7 +1035,10 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
         }
     }
 
-    protected void addExtraTimestampListParameters(Map<String, String> parameters) {
+    protected void addExtraTimestampListParameters(Map<String, String> parameters, Session session) {
+    }
+    
+    protected void addShowPrivateParameter(Map<String, String> parameters, Session session) {
     }
 
     protected boolean readObjectsFromOX(Folder folder, List<String> objectsToRead, BitSet requestedFields, DataObjectSet result, int limit, DataObjectFilter filter) throws UnsupportedContentOperationException, AuthenticationFailedException, OXCommunicationException, InternalUSMException {
@@ -1070,6 +1076,7 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
             }
             ids.put(element);
         }
+        addShowPrivateParameter(parameters, folder.getSession());
         JSONResult result = _ajaxAccess.doPut(getOXAjaxAccessPath(), UtilConstants.ACTION_LIST, folder.getSession(), parameters, ids);
         return getListOfResults(folder, requestedFields, result);
     }
