@@ -48,10 +48,10 @@
  */
 package com.openexchange.usm.database.ox;
 
-import java.sql.*;
-
+import java.sql.Connection;
+import java.sql.SQLException;
+import java.sql.Statement;
 import org.apache.commons.logging.Log;
-
 import com.openexchange.usm.api.database.DatabaseAccessException;
 import com.openexchange.usm.api.exceptions.USMSQLException;
 import com.openexchange.usm.util.SQLToolkit;
