@@ -48,7 +48,22 @@
  */
 package com.openexchange.usm.connector.commands;
 
-import static com.openexchange.usm.connector.commands.CommandConstants.*;
+import static com.openexchange.usm.connector.commands.CommandConstants.AVAILABLE_CONTENT_TYPES;
+import static com.openexchange.usm.connector.commands.CommandConstants.CLIENT_FIELD_PREFIX;
+import static com.openexchange.usm.connector.commands.CommandConstants.CONFLICT_RESOLUTION;
+import static com.openexchange.usm.connector.commands.CommandConstants.CONTEXT_ID;
+import static com.openexchange.usm.connector.commands.CommandConstants.CONTEXT_UUID;
+import static com.openexchange.usm.connector.commands.CommandConstants.CUSTOM_PROPERTIES;
+import static com.openexchange.usm.connector.commands.CommandConstants.DEVICE;
+import static com.openexchange.usm.connector.commands.CommandConstants.END_DATE;
+import static com.openexchange.usm.connector.commands.CommandConstants.FOLDER_TREE;
+import static com.openexchange.usm.connector.commands.CommandConstants.START_DATE;
+import static com.openexchange.usm.connector.commands.CommandConstants.SYNCID;
+import static com.openexchange.usm.connector.commands.CommandConstants.SYNC_CONTENT_TYPES;
+import static com.openexchange.usm.connector.commands.CommandConstants.TIME_ZONE;
+import static com.openexchange.usm.connector.commands.CommandConstants.USER;
+import static com.openexchange.usm.connector.commands.CommandConstants.USERID;
+import static com.openexchange.usm.connector.commands.CommandConstants.UUID_KEY;
 import java.io.BufferedReader;
 import java.io.IOException;
 import java.io.InputStreamReader;
