@@ -49,12 +49,7 @@
 
 package com.openexchange.usm.connector.commands;
 
-import static com.openexchange.usm.connector.commands.CommandConstants.CONTACT_IMAGE_DATA;
-import static com.openexchange.usm.connector.commands.CommandConstants.LENGTH;
-import static com.openexchange.usm.connector.commands.CommandConstants.MORE_AVAILABLE;
-import static com.openexchange.usm.connector.commands.CommandConstants.OFFSET;
-import static com.openexchange.usm.connector.commands.CommandConstants.SESSIONID;
-import static com.openexchange.usm.connector.commands.CommandConstants.TEMPID;
+import static com.openexchange.usm.connector.commands.CommandConstants.*;
 import java.io.IOException;
 import java.io.Writer;
 import javax.servlet.http.HttpServletRequest;
@@ -95,7 +90,7 @@ public class DownloadDataHandler extends NormalCommandHandler {
 
     private static final String _FIXED_HEADER = "{\"data\":{";
 
-    private static final String _MORE_AVAILABLE_JSON_DATA = "\"moreAvailable\":\"true\",";
+    private static final String _MORE_AVAILABLE_JSON_DATA = "\"moreAvailable\": true,";
 
     private static final String _DATA_PREFIX = "\"data\":\"";
 
@@ -146,27 +141,24 @@ public class DownloadDataHandler extends NormalCommandHandler {
         if (_id.getType() == ServerTempIdType.IMAGE)
             return handleRequestForContactImage();
         ResourceInputStream is = getResourceInputStream();
+        Writer w = null;
         try {
-            Writer w = null;
-            try {
-                if (_id.getType() == ServerTempIdType.MAIL)
-                    skipOffset(is);
-                _response.setContentType(ServletConstants.USM_JSON_CONTENT_TYPE);
-                _response.setContentLength(computeContentLength());
-                w = _response.getWriter();
-                writeResponse(is, w);
-                return null;
-            } catch (IOException e) {
-                throw new USMJSONAPIException(
-                    ConnectorBundleErrorCodes.DOWNLOAD_DATA_CAN_NOT_CREATE_RESPONSE_WRITER,
-                    ResponseStatusCode.INTERNAL_ERROR,
-                    "Can't write response",
-                    e);
-            } finally {
-                Toolkit.close(w);
-            }
+            if (_id.getType() == ServerTempIdType.MAIL)
+                skipOffset(is);
+            _response.setContentType(ServletConstants.USM_JSON_CONTENT_TYPE);
+            _response.setContentLength(computeContentLength());
+            w = _response.getWriter();
+            writeResponse(is, w);
+            return null;
+        } catch (IOException e) {
+            throw new USMJSONAPIException(
+                ConnectorBundleErrorCodes.DOWNLOAD_DATA_CAN_NOT_CREATE_RESPONSE_WRITER,
+                ResponseStatusCode.INTERNAL_ERROR,
+                "Can't write response",
+                e);
         } finally {
-            Toolkit.close(is);
+            Toolkit.close(is); // Close InputStream before OutputStream to make sure local resources are freed before request is completed
+            Toolkit.close(w);
         }
     }
 
