@@ -81,6 +81,10 @@ public class GetCachedDataHandler extends NormalCommandHandler {
 		String folderID = getStringParameter(FOLDERID, null);
 		long syncId = getSyncID();
 		DataObject[] resultElements = getCachedElements(syncId, folderID);
+		if (resultElements == null) {
+            throw new USMJSONAPIException(ConnectorBundleErrorCodes.SYNC_UPDATE_INVALID_SYNCID,
+                ResponseStatusCode.UNKNOWN_SYNCID, "Unknown SyncID "+ syncId + " for " + ((folderID == null) ? "folder hierarchy" : folderID));
+        }
 		_allFolders = resultElements;
 		JSONArray data = createResponseData(resultElements);
 		return new ResponseObject(ResponseStatusCode.SUCCESS, data);
