@@ -49,7 +49,8 @@
 
 package com.openexchange.usm.connector.commands;
 
-import static com.openexchange.usm.connector.commands.CommandConstants.*;
+import static com.openexchange.usm.connector.commands.CommandConstants.OBJECTIDS;
+import static com.openexchange.usm.connector.commands.CommandConstants.SESSIONID;
 import java.util.HashMap;
 import java.util.Map;
 import java.util.UUID;
