@@ -63,6 +63,8 @@ import static com.openexchange.usm.connector.commands.CommandConstants.TEMPID;
 import static com.openexchange.usm.connector.commands.CommandConstants.TITLE;
 import static com.openexchange.usm.connector.commands.CommandConstants.TYPE;
 import static com.openexchange.usm.connector.commands.CommandConstants.UUID_KEY;
+import static com.openexchange.usm.json.ConnectorBundleErrorCodes.*;
+import static com.openexchange.usm.json.response.ResponseStatusCode.*;
 import java.util.BitSet;
 import java.util.Collection;
 import java.util.List;
@@ -89,6 +91,7 @@ import com.openexchange.usm.api.session.DataObject;
 import com.openexchange.usm.api.session.Folder;
 import com.openexchange.usm.api.session.FolderType;
 import com.openexchange.usm.api.session.Session;
+import com.openexchange.usm.contenttypes.util.UtilConstants;
 import com.openexchange.usm.datatypes.contacts.ContactDistributionMember;
 import com.openexchange.usm.datatypes.contacts.Image;
 import com.openexchange.usm.datatypes.tasks.calendar.CommonCalendarTasksFieldNames;
@@ -99,6 +102,7 @@ import com.openexchange.usm.json.USMJSONAPIException;
 import com.openexchange.usm.json.USMJSONServlet;
 import com.openexchange.usm.json.USMJSONVersion;
 import com.openexchange.usm.json.USMSessionCredentials;
+import com.openexchange.usm.json.response.ResponseObject;
 import com.openexchange.usm.json.response.ResponseStatusCode;
 import com.openexchange.usm.json.streaming.ServerTempId;
 import com.openexchange.usm.session.dataobject.DataObjectUtil;
@@ -107,6 +111,8 @@ import com.openexchange.usm.util.Toolkit;
 public abstract class NormalCommandHandler extends BaseCommandHandler {
 
     private static final String DELETE_EXCEPTIONS = "delete_exceptions";
+    
+    private static final String OWN_RIGHTS = "own_rights";
 
     protected DataObject[] _allFolders;
 
@@ -469,4 +475,65 @@ public abstract class NormalCommandHandler extends BaseCommandHandler {
             _servlet.getJournal().debug(
                 _session + command + " modified SyncID(" + uuid + "):" + oldSyncID + "->" + newSyncID + "(" + tempSyncID + ")");
     }
+    
+    protected ResponseObject createCannotLockFolderResponse(String command, String folderType, String folderUUID, String previousAcquirer) {
+        String errorMessage = "Can not gain exclusive access to " + folderType + "folder " + folderUUID + " for " + command + ": locked by " + previousAcquirer;
+        _servlet.getJournal().warn(_session.toString() + ' ' + errorMessage);
+        return new ResponseObject(TEMPORARY_NOT_AVAILABLE, COMMAND_FAILED_TO_ACQUIRE_LOCK_ON_FOLDER, errorMessage, null, null);
+    }
+    
+    protected boolean checkCreatePermissionsAllObjects(int own_rights) {
+        return (own_rights & 0x7F) >= 2;
+    }
+
+    protected boolean checkDeletePermissionsAllObjects(int own_rights) {
+        return (own_rights & 0xFE00000) >= 0x400000;
+    }
+
+    protected boolean checkDeletePermissionsOwnObjects(int own_rights) {
+        return (own_rights & 0xFE00000) >= 0x200000;
+    }
+
+    protected boolean checkDeletePermissions(int own_rights, DataObject object) {
+        return isOwnObject(object) ? checkDeletePermissionsOwnObjects(own_rights) : checkDeletePermissionsAllObjects(own_rights);
+    }
+
+    protected boolean checkModifyPermissions(int ownRights, DataObject object) {
+        return isOwnObject(object) ? checkModifyPermissionsOwnObjects(ownRights) : checkModifyPermissionsAllObjects(ownRights);
+    }
+
+    private boolean checkModifyPermissionsAllObjects(int ownRights) {
+        return (ownRights & 0x1FC000) >= 0x8000;
+    }
+
+    private boolean checkModifyPermissionsOwnObjects(int ownRights) {
+        return (ownRights & 0x1FC000) >= 0x4000;
+    }
+
+    protected boolean isOwnObject(DataObject object) {
+        if (DefaultContentTypes.MAIL_CODE == object.getContentType().getCode())
+            return true; // mails can be only own objects
+        int userId = object.getSession().getUserIdentifier();
+        Object createdBy = object.getFieldContent(UtilConstants.CREATED_BY);
+        return (createdBy instanceof String) && createdBy.equals(String.valueOf(userId));
+    }
+    
+    protected int getOwnRights(Folder folder) {
+        Object o = folder.getFieldContent(OWN_RIGHTS);
+        if (o instanceof Number)
+            return ((Number) o).intValue();
+        try {
+            BitSet requestedFields = new BitSet();
+            int fieldIndex = folder.getFieldIndex(OWN_RIGHTS);
+            requestedFields.set(fieldIndex);
+            folder.getContentType().getTransferHandler().readFolder(folder, requestedFields);
+            o = folder.getFieldContent(fieldIndex);
+            if (o instanceof Number)
+                return ((Number) o).intValue();
+        } catch (USMException ignored) {
+            // If we could not read the folder, e.g. if the folder has been deleted, we assume that the user has no rights for elements in
+            // that folder
+        }
+        return 0;
+    }
 }
