@@ -48,7 +48,11 @@
  */
 package com.openexchange.usm.connector.commands;
 
-import static com.openexchange.usm.connector.commands.CommandConstants.*;
+import static com.openexchange.usm.connector.commands.CommandConstants.FOLDERID;
+import static com.openexchange.usm.connector.commands.CommandConstants.OBJECTIDS;
+import static com.openexchange.usm.connector.commands.CommandConstants.PROPERTIES;
+import static com.openexchange.usm.connector.commands.CommandConstants.SESSIONID;
+import static com.openexchange.usm.connector.commands.CommandConstants.SYNCID;
 import java.util.ArrayList;
 import java.util.List;
 import javax.servlet.http.HttpServletRequest;
@@ -81,7 +85,7 @@ public class ReadDataHandler extends NormalCommandHandler {
 
     public ReadDataHandler(USMJSONServlet servlet, HttpServletRequest request) throws USMJSONAPIException {
         super(servlet, request);
-	}
+    }
 
 	@Override
 	public ResponseObject handleRequest() throws USMJSONAPIException {
