@@ -48,7 +48,7 @@
  */
 package com.openexchange.usm.connector.commands;
 
-import static com.openexchange.usm.connector.commands.CommandConstants.*;
+import static com.openexchange.usm.connector.commands.CommandConstants.SESSIONID;
 import java.util.ArrayList;
 import java.util.BitSet;
 import java.util.List;
