@@ -48,8 +48,10 @@
  */
 package com.openexchange.usm.connector.commands;
 
-import static com.openexchange.usm.connector.commands.CommandConstants.*;
-import static com.openexchange.usm.datatypes.tasks.calendar.UserParticipantObject.*;
+import static com.openexchange.usm.connector.commands.CommandConstants.SESSIONID;
+import static com.openexchange.usm.connector.commands.CommandConstants.UID;
+import static com.openexchange.usm.datatypes.tasks.calendar.UserParticipantObject.CONFIRMATION;
+import static com.openexchange.usm.datatypes.tasks.calendar.UserParticipantObject.CONFIRM_MESSAGE;
 import javax.servlet.http.HttpServletRequest;
 import com.openexchange.usm.api.contenttypes.AppointmentContentType;
 import com.openexchange.usm.api.contenttypes.ContentType;
