@@ -49,7 +49,11 @@
 
 package com.openexchange.usm.connector.commands;
 
-import static com.openexchange.usm.connector.commands.CommandConstants.*;
+import static com.openexchange.usm.connector.commands.CommandConstants.CONFLICT_RESOLUTION;
+import static com.openexchange.usm.connector.commands.CommandConstants.CREATED;
+import static com.openexchange.usm.connector.commands.CommandConstants.FOLDERID;
+import static com.openexchange.usm.connector.commands.CommandConstants.LIMIT;
+import static com.openexchange.usm.connector.commands.CommandConstants.SESSIONID;
 import java.util.Arrays;
 import javax.servlet.http.HttpServletRequest;
 import org.json.JSONObject;
@@ -91,15 +95,15 @@ public class SyncInitHandler extends SyncCommandHandler {
         try {
             readOptionalLimit();
             ConflictResolution conflictResolution = getOptionalConflictResolution();
-            SyncResult result = computeSyncInit(folderUUID, conflictResolution);
-            initializeErrorMap(result);
+            _syncResult = computeSyncInit(folderUUID, conflictResolution);
+            initializeErrorMap(_syncResult);
             Folder folder = null;
             if (folderUUID != null)
                 folder = getFolderByUUID(folderUUID);
-            _cachedElements = new DataObjectSet(result.getNewState());
-            long syncId = finishProcessingAndSaveNewState(result, folder, result.getTimestamp());
-            JSONObject response = createResponseFromSyncResults(result, syncId);
-            logSyncData(" syncInit", folderUUID, 0L, syncId, result.getTimestamp());
+            _cachedElements = new DataObjectSet(_syncResult.getNewState());
+            long syncId = finishProcessingAndSaveNewState(_syncResult, folder, _syncResult.getTimestamp());
+            JSONObject response = createResponseFromSyncResults(_syncResult, syncId);
+            logSyncData(" syncInit", folderUUID, 0L, syncId, _syncResult.getTimestamp());
             return new ResponseObject(getSuccessResponseCode(), response);
         } finally {
             _session.unlock(lockKey);
