@@ -142,6 +142,8 @@ public class SyncUpdateHandler extends SyncCommandHandler {
             readOptionalLimit();
             ConflictResolution conflictResolution = getOptionalConflictResolution();
             _syncID = getSyncID();
+            if(folderUUID != null)
+                setFolderToSync(folderUUID);
             // Check if the client used an old SyncKey (repeated usage of an old syncKey indicates a problem)
             boolean usedOldSyncKey = _session.getNewestTimestamp(_folderToSync == null ? "" : _folderToSync.getID()) > _syncID;
             if (usedOldSyncKey) {
@@ -161,15 +163,12 @@ public class SyncUpdateHandler extends SyncCommandHandler {
             }
             initializeErrorMap(_syncResult);
             long syncId = _syncResult.getTimestamp();
-            Folder folder = null;
-            if (folderUUID != null)
-                folder = getFolderByUUID(folderUUID);
-            if (_recurrenceUUIDMap.size() > 0 && folder != null) {
+            if (_recurrenceUUIDMap.size() > 0 && _folderToSync != null) {
                 // make additional update to retrieve all created exception objects on the server,
                 // and replace the uuids created on the server with the original uuids sent from the client
-                retrieveExceptionsFromServerAndSetUUIDs(syncId, folder);
+                retrieveExceptionsFromServerAndSetUUIDs(syncId, _folderToSync);
             }
-            syncId = finishProcessingAndSaveNewState(_syncResult, folder, syncId);
+            syncId = finishProcessingAndSaveNewState(_syncResult, _folderToSync, syncId);
             JSONObject response = createResponseFromSyncResults(_syncResult, syncId);
             logSyncData(" syncUpdate", folderUUID, _syncID, syncId, _syncResult.getTimestamp());
             if (usedOldSyncKey || isUnnecessaryAccess(folderUUID, response))
@@ -316,7 +315,6 @@ public class SyncUpdateHandler extends SyncCommandHandler {
 				return _session.syncFolderChangesWithServer(syncId, _limit, null, true, conflictResolution,
                     _folderClientChangesArray);
 			}
-			setFolderToSync(folderID);
 			_serverChangesMayBeAvailable = _session.needsSynchronization(_folderToSync.getID());
 			_clientChangesArray = filterDataObjectsWithErrors(buildClientRequestArray(_folderToSync, syncId, conflictResolution));
 			if (_syncIdForUpdate > 0) {
