@@ -134,6 +134,7 @@ public interface ConnectorBundleErrorCodes {
 	int SYNC_INSUFFICIENT_DELETION_RIGHTS = 0x610139;
     int MULTIPLE_OPERATIONS_ON_SAME_UUID = 0x61013A;
     int OX_ERROR_FOR_SERIES_EXCEPTION = 0x61013B;
+    int COMMAND_SYNC_CAN_NOT_READ_CACHED_ELEMENTS = 0x61013C;
 
 	int SYNC_INSUFFICIENT_CREATION_RIGHTS = 0x610140;
 	int SYNC_PIM_ATTACHMENT_CREATION_FAILED = 0x610141;
@@ -163,6 +164,7 @@ public interface ConnectorBundleErrorCodes {
 	int INVALID_ALIAS_FOR_SERVLET = 0x610207;
 	int EXCEPTION_IN_SERVLET = 0x610208;
 	int EXCEPTION_IN_SERVLET_2 = 0x610209;
+    int SERVLET_SESSIONMANAGER_NOT_AVAILABLE = 0x61020A;
 
 	// 610300-6103FF: Login error codes
 	int LOGIN_JSON_ERROR = 0x610300;
@@ -236,6 +238,7 @@ public interface ConnectorBundleErrorCodes {
 	int RESOLVE_RECIPIENTS_CAN_NOT_GET_CONTACTS = 0x610D03;
 	int RESOLVE_RECIPIENTS_CAN_NOT_CREATE_RESPONCE = 0x610D04;
 	int RESOLVE_RECIPIENTS_WRONG_NAMES_ARRAY = 0x610D05;
+    int RESOLVE_IDS_TEMPORARY_DOWN_OR_BUSY = 0x610D06;
 
 	// 610E00-610EFF: MoveItems error codes
 	int MOVE_ITEMS_INTERNAL_ERROR = 0x610E00;
@@ -243,11 +246,11 @@ public interface ConnectorBundleErrorCodes {
 	int MOVE_ITEMS_INVALID_SYNC_ID = 0x610E02;
 	int MOVE_ITEMS_SAME_SOURCE_DEST = 0x610E03;
 	int MOVE_ITEMS_INTERNAL_ERROR_2 = 0x610E04;
-	int MOVE_ITEMS_INVALID_SYNC_ID_2 = 0x610E05;
+	int MOVE_ITEMS_JSON_ERROR_2 = 0x610E05;
 	int MOVE_ITEMS_INTERNAL_ERROR_3 = 0x610E06;
 	int MOVE_ITEMS_JSON_ERROR = 0x610E07;
 	int MOVE_ITEMS_INTERNAL_ERROR_4 = 0x610E08;
-	int MOVE_ITEMS_INTERNAL_ERROR_5 = 0x610E09;
+	
 
 	// 610F00-610FFF: GetCachedData error codes
 	int GET_CACHED_DATA_GET_ELEMENTS_ERROR = 0x610F00;
