@@ -48,6 +48,7 @@
  */
 package com.openexchange.usm.json;
 
+import java.util.concurrent.ExecutorService;
 import org.osgi.service.component.ComponentContext;
 import org.osgi.service.http.HttpService;
 import com.openexchange.usm.api.contenttypes.ContentTypeManager;
@@ -78,7 +79,10 @@ public class HttpWrapper {
 				.getName());
 		ConfigurationManager configurationManager = (ConfigurationManager) context
 				.locateService(ConfigurationManager.class.getName());
-		
+		ExecutorService executorService = (ExecutorService) context
+            .locateService(ExecutorService.class.getName());
+		USMJSONServlet.setExecutorService(executorService);
+
 
 		_servlet.activate(sessionManager, contentTypeManager, journal.getLog(USMJSONServlet.class), httpService,
 				configurationManager);
@@ -90,5 +94,6 @@ public class HttpWrapper {
 	 */
 	public void deactivate(ComponentContext context) {
 		_servlet.deactivate();
+		USMJSONServlet.setExecutorService(null);
 	}
 }
