@@ -48,12 +48,9 @@
  */
 package com.openexchange.usm.json;
 
-import static com.openexchange.usm.connector.commands.CommandConstants.*;
-
+import static com.openexchange.usm.connector.commands.CommandConstants.EXTRA_PROPERTIES_PREFIX;
 import java.util.BitSet;
-
 import org.json.JSONObject;
-
 import com.openexchange.usm.api.contenttypes.AppointmentContentType;
 import com.openexchange.usm.api.contenttypes.ContentType;
 import com.openexchange.usm.api.contenttypes.ContentTypeField;
