@@ -68,6 +68,9 @@ public class ServletConstants {
 	public static final String USM_INVALIDATE_OBJECTS = "invalidateObjects";
 	public static final String USM_LOCATE_OBJECTS = "locateObjects";
 	public static final String USM_SET_CONFIRMATION_STATUS = "setConfirmationStatus";
+    public static final String USM_DOWNLOAD_DATA = "downloadData";
+    public static final String USM_UPLOAD_DATA = "uploadData";
+    public static final String USM_CLEAR_DATA = "clearData";
 
 	public static final String TEXT_JAVASCRIPT = "text/javascript";
 	public static final String UTF_ENCODING_8 = "UTF-8";
