@@ -49,11 +49,13 @@
 
 package com.openexchange.usm.json;
 
-import static com.openexchange.usm.json.ServletConstants.PROTOCOL;
+import static com.openexchange.usm.json.ServletConstants.*;
 import java.io.IOException;
 import java.io.OutputStreamWriter;
 import java.io.Writer;
 import java.util.Map;
+import java.util.concurrent.ExecutorService;
+import java.util.concurrent.atomic.AtomicReference;
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServlet;
 import javax.servlet.http.HttpServletRequest;
@@ -65,6 +67,7 @@ import org.json.JSONObject;
 import org.osgi.service.http.HttpService;
 import org.osgi.service.http.NamespaceException;
 import com.openexchange.usm.api.contenttypes.ContentTypeManager;
+import com.openexchange.usm.api.exceptions.TemporaryDownOrBusyException;
 import com.openexchange.usm.api.exceptions.USMException;
 import com.openexchange.usm.api.exceptions.USMJSONException;
 import com.openexchange.usm.api.exceptions.USMResourceAccessException;
@@ -87,10 +90,30 @@ public class USMJSONServlet extends HttpServlet {
     private static final String COMMAND = "action";
 
     /**
-	 *
-	 */
+     *
+     */
     private static final long serialVersionUID = 1L;
 
+    private static AtomicReference<ExecutorService> EXECUTOR_SERVICE_REF = new AtomicReference<ExecutorService>();
+
+    /**
+     * Sets the specified <code>ExecutorService</code> instance
+     *
+     * @param executorService The <code>ExecutorService</code> instance
+     */
+    public static void setExecutorService(final ExecutorService executorService) {
+        EXECUTOR_SERVICE_REF.set(executorService);
+    }
+
+    /**
+     * Gets the <code>ExecutorService</code> instance
+     *
+     * @return The <code>ExecutorService</code> instance or <code>null</code>
+     */
+    public static ExecutorService getExecutorService() {
+        return EXECUTOR_SERVICE_REF.get();
+    }
+
     private final transient JSONSessionInitializer _sessionInitializer = new JSONSessionInitializer(this);
 
     private transient SessionManager _sessionManager;
@@ -136,10 +159,10 @@ public class USMJSONServlet extends HttpServlet {
     private transient int _maxInlineAttachmentSize;
 
     private transient AccessLimiter _accessLimiter;
-
+    
     /**
      * the activate method; register the httpServer object, set the Servlet alias
-     * 
+     *
      * @param sessionManager
      * @param contentTypeManager
      * @param log
@@ -256,7 +279,7 @@ public class USMJSONServlet extends HttpServlet {
         _contentTypeManager = null;
         _configurationManager = null;
         _httpService = null;
-        _journal = null;
+        // _journal = null; // Do not remove _journal reference to allow logging in other threads to continue as long as possible
         _pingTimestamps = null;
     }
 
@@ -274,12 +297,13 @@ public class USMJSONServlet extends HttpServlet {
             _journal.error("Open-Xchange USM/JSON: Internal server error in " + command, error);
             sendError(response, HttpStatus.SC_INTERNAL_SERVER_ERROR);
         }
+        
         if (_journal.isDebugEnabled()) {
             _journal.debug(generateTimeLog(session, command, System.currentTimeMillis() - startTime));
         }
     }
-
-    protected Session handleCommand(HttpServletRequest request, HttpServletResponse response, String command) throws JSONException, IOException {
+    
+    private Session handleCommand(HttpServletRequest request, HttpServletResponse response, String command) throws JSONException, IOException {
         ResponseObject result;
         CommandHandler handler = null;
         boolean printedError = false;
@@ -314,8 +338,9 @@ public class USMJSONServlet extends HttpServlet {
         }
         if (result != null) {
             logResult(command, result, handler, printedError);
-            if (handler != null)
+            if (handler != null) {
                 handler.disposeResources();
+            }
             sendResponse(response, result);
         }
         return (handler == null) ? null : handler.getSession();
@@ -323,7 +348,14 @@ public class USMJSONServlet extends HttpServlet {
 
     private static void sendResponse(HttpServletResponse response, ResponseObject result) throws JSONException, IOException {
         response.setContentType(ServletConstants.USM_JSON_CONTENT_TYPE);
-        response.setContentLength(computeContentLength(result));
+        long contentLength = computeContentLength(result);
+        if(contentLength > 0L) {
+            if(contentLength <= Integer.MAX_VALUE) {
+                response.setContentLength((int) contentLength);
+            } else {
+                response.setHeader( "Content-Length", String.valueOf(contentLength));
+            }
+        }
         Writer w = response.getWriter();
         if (w != null) {
             result.write(w);
@@ -374,7 +406,7 @@ public class USMJSONServlet extends HttpServlet {
         }
     }
 
-    private static int computeContentLength(ResponseObject result) throws JSONException, IOException {
+    private static long computeContentLength(ResponseObject result) throws JSONException, IOException {
         ByteCountOutputStream counter = new ByteCountOutputStream();
         OutputStreamWriter outputStreamWriter = new OutputStreamWriter(counter, ServletConstants.UTF_ENCODING_8);
         result.write(outputStreamWriter);
@@ -439,8 +471,14 @@ public class USMJSONServlet extends HttpServlet {
         }
     }
 
-    public SessionManager getSessionManager() {
-        return _sessionManager;
+    public SessionManager getSessionManager() throws TemporaryDownOrBusyException {
+        SessionManager m = _sessionManager;
+        if (m != null)
+            return m;
+        throw new TemporaryDownOrBusyException(
+            ConnectorBundleErrorCodes.SERVLET_SESSIONMANAGER_NOT_AVAILABLE,
+            "USM SessionManager not available",
+            null);
     }
 
     public ContentTypeManager getContentTypeManager() {
@@ -456,18 +494,20 @@ public class USMJSONServlet extends HttpServlet {
     }
 
     public Session getSession(String user, String password, String device, String clientIP, Map<String, String> xHeaders) throws USMException {
-        Session session = _sessionManager.getSession(user, password, PROTOCOL, device, _sessionInitializer, clientIP, xHeaders);
+        Session session = getSessionManager().getSession(user, password, PROTOCOL, device, _sessionInitializer, clientIP, xHeaders);
         return session;
     }
 
     public long getPingInterval() {
         synchronized (_pingSynchronizeObject) {
             int nextIndex = (_pingTimestampsIndex + 1 >= _pingTimestamps.length) ? 0 : _pingTimestampsIndex + 1;
-            if (_pingTimestamps[nextIndex] == 0L)
+            if (_pingTimestamps[nextIndex] == 0L) {
                 return _minPingInterval;
+            }
             long deltaT = Math.max(_pingTimestamps[_pingTimestampsIndex] - _pingTimestamps[nextIndex], 1L);
-            if (deltaT >= ONE_SECOND * _pingSampleSize)
+            if (deltaT >= ONE_SECOND * _pingSampleSize) {
                 return _minPingInterval;
+            }
             return Math.min(_maxPingInterval, _minPingInterval * ONE_SECOND / deltaT);
         }
     }
@@ -475,19 +515,22 @@ public class USMJSONServlet extends HttpServlet {
     public void newPingRequestArrived() {
         synchronized (_pingSynchronizeObject) {
             _pingTimestampsIndex++;
-            if (_pingTimestampsIndex >= _pingTimestamps.length)
+            if (_pingTimestampsIndex >= _pingTimestamps.length) {
                 _pingTimestampsIndex = 0;
+            }
             _pingTimestamps[_pingTimestampsIndex] = System.currentTimeMillis();
         }
     }
 
     private static String generateTimeLog(Session session, String command, long duration) {
-        if (session == null)
+        if (session == null) {
             return "No session: " + command + " executed in " + duration + " ms.";
+        }
         Object numberOfCalls = session.getCustomProperty(OXJSONPropertyNames.NUMBER_OF_CALLS);
         Object accumulatedTime = session.getCustomProperty(OXJSONPropertyNames.ACCUMULATED_TIME);
-        if (numberOfCalls == null || accumulatedTime == null)
+        if (numberOfCalls == null || accumulatedTime == null) {
             return session + ": " + command + " executed in " + duration + " ms, no OX calls made.";
+        }
         return session + ": " + command + " executed in " + duration + " ms, " + numberOfCalls + " OX calls took " + accumulatedTime + " ms.";
     }
 
