@@ -68,9 +68,9 @@ public final class USMJSONVersion {
     /**
      * USM JSON versions
      */
-    public static final String VERSION = "7.4.1-5";
+    public static final String VERSION = "7.4.2-12";
 
-    public static final String BUILD_NUMBER = "c8919e9a1cd6835d759fd5dffc00a6fc1c269bd5- 6105";
+    public static final String BUILD_NUMBER = "f559a29e3b5c1e0801a653c473d14fe8063150b2- 6528";
 
     public static final String _CLIENT_USM_JSON_VERSION_KEY = "json.Prot.Version";
 
@@ -78,7 +78,9 @@ public final class USMJSONVersion {
 
     public static final USMJSONVersion SUPPORTS_ATTACHMENT_STREAMING = new USMJSONVersion("2.0.0");
 
-    public static final USMJSONVersion SUPPORTS_CONTACT_IMAGE_STREAMING = new USMJSONVersion("2.1.0");
+    public static final USMJSONVersion SUPPORTS_CONTACT_IMAGE_STREAMING = new USMJSONVersion("2.2.0");
+    
+    public static final USMJSONVersion SUPPORTS_CONTACT_IMAGE_STREAMING_FALSE_33754 = new USMJSONVersion("2.1.0");
 
     private static final USMJSONVersion _CURRENT_VERSION = _SUPPORTS_FILTERED_OUT_LARGE_OBJECTS_STATUS_CODE;
 
@@ -91,6 +93,7 @@ public final class USMJSONVersion {
             synchronized (_supportedVersions) {
                 if (_supportedVersions.isEmpty()) {
                     _supportedVersions.add(SUPPORTS_CONTACT_IMAGE_STREAMING);
+                    _supportedVersions.add(SUPPORTS_CONTACT_IMAGE_STREAMING_FALSE_33754);
                     _supportedVersions.add(SUPPORTS_ATTACHMENT_STREAMING);
                     _supportedVersions.add(_SUPPORTS_FILTERED_OUT_LARGE_OBJECTS_STATUS_CODE);
                 }
