@@ -212,6 +212,12 @@ public class StreamingMimeMailBuilder extends AbstractMimeMailBuilder {
                     USMMimeMessage nestedPart = new USMMimeMessage(javax.mail.Session.getInstance(new Properties()));
                     buildPart(nestedPart, body);
                     part.setContent(nestedPart, CONTENTTYPE_RFC822);
+                } else if (contentTypeOfPart.startsWith(CONTENTTYPE_TEXT_PREFIX)) {
+                        //add headers
+                        String encoding = getValue(headers, CONTENT_TRANSFER_ENCODING, 0, "quoted-printable");
+                        appendHeaderConditional(part, CONTENT_TRANSFER_ENCODING_UPPER, encoding);
+                        part.setHeader(CONTENT_TYPE_UPPER, contentTypeOfPart);
+                        setBodyOfPart(part, contentTypeOfPart, body, headers);
                 } else {
                     String encoding = getValue(headers, CONTENT_TRANSFER_ENCODING, 0, null);
                     appendHeaderConditional(part, CONTENT_TRANSFER_ENCODING_UPPER, encoding);
