@@ -62,8 +62,6 @@ import com.openexchange.groupware.container.DataObject;
 import com.openexchange.usm.api.contenttypes.DefaultContentTypes;
 import com.openexchange.usm.ox_event.OXEventListener;
 import com.openexchange.usm.ox_event.OXEventManager;
-import com.openexchange.group.*;
-import com.openexchange.resource.*;
 
 /**
  * 
