@@ -105,6 +105,7 @@ import com.openexchange.usm.ox_json.JSONResultType;
 import com.openexchange.usm.ox_json.OXJSONAccess;
 import com.openexchange.usm.ox_json.OXJSONPropertyNames;
 import com.openexchange.usm.ox_json.OXResource;
+import com.openexchange.usm.util.OXJSONUtil;
 
 /**
  * @author afe
@@ -112,7 +113,7 @@ import com.openexchange.usm.ox_json.OXResource;
 public class OXJSONAccessImpl implements OXJSONAccess {
 
     private static final String OX_REQUEST_INFORMATION_FIELD = "OXJSONAccessImpl.OXRequestInformation";
-    
+
     private static final String CUSTOM_HOST_HEADER = "X-Host";
 
     private static final int MAX_RETRY = 10;
@@ -169,7 +170,7 @@ public class OXJSONAccessImpl implements OXJSONAccess {
     private HttpURL _oxJSONBaseURL;
 
     private long _lastRedirect = 0L;
-    
+
     private boolean _passClientHostHeader = false;
 
     public void login(Session session) throws AuthenticationFailedException, OXCommunicationException {
@@ -247,7 +248,7 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         method.addParameter("password", password);
         for (String header : session.getXRequestHeaders().keySet()) {
             if (CUSTOM_HOST_HEADER.equals(header) && _passClientHostHeader) {
-                    method.setRequestHeader(header, session.getXRequestHeaders().get(header));
+                method.setRequestHeader(header, session.getXRequestHeaders().get(header));
             } else
                 method.setRequestHeader(header, session.getXRequestHeaders().get(header));
         }
@@ -506,7 +507,7 @@ public class OXJSONAccessImpl implements OXJSONAccess {
             }
             for (int i = 0; i < MAX_RETRY && shouldRetryRequest(result); i++) {
                 if (_journal.isDebugEnabled())
-                    _journal.debug("Server returned error from category: " + OXJSONSupport.getJSONErrorCategory(result.getJSONObject()) + ". Retrying request..");
+                    _journal.debug("Server returned error from category: " + OXJSONUtil.getJSONErrorCategory(result.getJSONObject()) + ". Retrying request..");
                 result = executeMethodOnce(session, data.getHttpClient(), method);
             }
             if (shouldRetryRequest(result))
@@ -558,24 +559,25 @@ public class OXJSONAccessImpl implements OXJSONAccess {
     }
 
     private static boolean isSynchronizationConflictError(JSONResult result) {
-        return result.getResultType() == JSONResultType.Error && OXJSONSupport.ERROR_CODE_OBJECT_CHANGED.equals(OXJSONSupport.getJSONErrorCode(result.getJSONObject()));
+        return result.getResultType() == JSONResultType.Error && OXJSONUtil.ERROR_CODE_OBJECT_CHANGED.equals(OXJSONUtil.getJSONErrorCode(result.getJSONObject()));
     }
 
     private static boolean shouldRetryRequest(JSONResult result) {
         if (result.getResultType() != JSONResultType.Error)
             return false;
-        String errorCategory = OXJSONSupport.getJSONErrorCategory(result.getJSONObject());
-        return OXJSONSupport.CATEGORY_RESOURCE_TEMPORARY_DOWN.equals(errorCategory)
+        String errorCategory = OXJSONUtil.getJSONErrorCategory(result.getJSONObject());
+        return OXJSONUtil.CATEGORY_RESOURCE_TEMPORARY_DOWN.equals(errorCategory)
         // || OXJSONSupport.CATEGORY_RESOURCE_FULL_OR_BUSY.equals(errorCategory)
-        || OXJSONSupport.CATEGORY_SOCKET_CONNECTION_CORRUPT.equals(errorCategory) || OXJSONSupport.CATEGORY_SUBSYSTEM_DOWN.equals(errorCategory);
+        || OXJSONUtil.CATEGORY_SOCKET_CONNECTION_CORRUPT.equals(errorCategory) || OXJSONUtil.CATEGORY_SUBSYSTEM_DOWN.equals(errorCategory);
     }
 
     private ResourceInputStreamImpl accessResource(Session session, String path, Map<String, String> parameters) throws AuthenticationFailedException, OXCommunicationException {
         GetMethod method = null;
         boolean freeMethod = true;
         try {
+            String resourceMessage = session + " GET " + _oxJSONBaseURLasString + " + " + path;
             if (_journal.isDebugEnabled())
-                _journal.debug(session + " GET " + _oxJSONBaseURLasString + " + " + path);
+                _journal.debug(resourceMessage);
             OXConnectionData connectionData = obtainConnectionData(session);
             if (parameters == null) {
                 HttpURL url = getURLFromString(path);
@@ -585,6 +587,9 @@ public class OXJSONAccessImpl implements OXJSONAccess {
                         url);
                 }
                 method = new GetMethod();
+                String query = url.getQuery();
+                query = query + "&session=" + connectionData.getSessionID();
+                url.setQuery(query);
                 method.setURI(url);
             } else {
                 String url = getBaseURL() + path;
@@ -603,7 +608,7 @@ public class OXJSONAccessImpl implements OXJSONAccess {
             String contentType = responseHeader.getValue().toLowerCase();
             if (isValidResourceContentType(contentType)) {
                 freeMethod = false;
-                ResourceInputStreamImpl ris = new ResourceInputStreamImpl(this, session, connectionData, method, contentType);
+                ResourceInputStreamImpl ris = new ResourceInputStreamImpl(this, session, connectionData, method, contentType, resourceMessage);
                 return ris;
             }
             if (contentType == null || !contentType.startsWith(TEXT_HTML))
@@ -635,17 +640,15 @@ public class OXJSONAccessImpl implements OXJSONAccess {
 
     public OXResource getResource(Session session, String path, Map<String, String> parameters) throws AuthenticationFailedException, OXCommunicationException {
         obtainRequiredLock(session, "GET " + path + ' ' + parameters);
+        ResourceInputStreamImpl data = accessResource(session, path, parameters);
         try {
-            ResourceInputStreamImpl data = accessResource(session, path, parameters);
             try {
                 return new OXResource(data.getContentType(), extractResponseBody(data.getMethod()));
-            } catch (IOException e) {
-                throw new OXCommunicationException(OXJSONErrorCode.ACCESSIMPL_CAN_NOT_READ_RESOURCE, e);
             } finally {
-                data.getMethod().releaseConnection();
+                data.close();
             }
-        } finally {
-            releaseLock(session);
+        } catch (IOException e) {
+            throw new OXCommunicationException(OXJSONErrorCode.ACCESSIMPL_CAN_NOT_READ_RESOURCE, e);
         }
     }
 
@@ -767,11 +770,15 @@ public class OXJSONAccessImpl implements OXJSONAccess {
     private static byte[] extractResponseBody(HttpMethod method) throws IOException {
         ByteArrayOutputStream byteArrayStream = new ByteArrayOutputStream(RESOURCE_BUFFER_DEFAULT_SIZE);
         InputStream inputStream = method.getResponseBodyAsStream();
-        byte[] data = new byte[4096];
-        for (int count = inputStream.read(data); count > 0; count = inputStream.read(data))
-            byteArrayStream.write(data, 0, count);
-        byteArrayStream.close();
-        return byteArrayStream.toByteArray();
+        try {
+            byte[] data = new byte[4096];
+            for (int count = inputStream.read(data); count > 0; count = inputStream.read(data))
+                byteArrayStream.write(data, 0, count);
+            byteArrayStream.close();
+            return byteArrayStream.toByteArray();
+        } finally {
+            inputStream.close();
+        }
     }
 
     private static String extractResponseBodyAsString(HttpMethodBase method) throws IOException {
@@ -850,7 +857,10 @@ public class OXJSONAccessImpl implements OXJSONAccess {
             if (tryLock(session, requestInformation))
                 return;
         } catch (InterruptedException e) {
-            // fall through
+            throw new OXCommunicationException(
+                OXJSONErrorCode.INTERRUPTED_WHILE_WAITING_FOR_ACCESS,
+                "Interrupted while waiting for exclusive access to OX server, locked by " + session + '/' + getRequestInformation(session),
+                e);
         }
         throw new OXCommunicationException(
             OXJSONErrorCode.FAILED_TO_GAIN_EXCLUSIVE_OX_ACCESS,
@@ -871,7 +881,7 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         if (data != null) {
             ResourceInputStreamImpl currentRIS = data.getCurrentResourceInputStream();
             if (currentRIS != null && currentRIS.getLastActivity() < System.currentTimeMillis() - _STREAM_INACTIVITY_TIMEOUT) {
-                _journal.info("Closing ResourceInputStream due to long inactivity (was locked by " + getRequestInformation(session) + ')');
+                _journal.info("Closing ResourceInputStream due to long inactivity (was locked by " + getRequestInformation(session) + "): " + currentRIS);
                 try {
                     currentRIS.close();
                 } catch (IOException ignored) {
@@ -886,7 +896,8 @@ public class OXJSONAccessImpl implements OXJSONAccess {
     }
 
     public void releaseLock(Session session) {
-        setRequestInformation(session, null);
+        // Do not clear request information, keep data until next request to have it available for concurrency issues
+        // setRequestInformation(session, null);
         try {
             // Probably not necessary, just to be sure to avoid a deadlock in case one of the access methods fails to cleanup properly
             session.getOXConnectionLock().unlock();
