@@ -49,8 +49,6 @@
 
 package com.openexchange.usm.ox_json.impl;
 
-import java.io.IOException;
-import java.io.InputStream;
 import java.util.Map;
 import org.apache.commons.httpclient.MultiThreadedHttpConnectionManager;
 import org.json.JSONArray;
@@ -98,8 +96,10 @@ public class OXJSONAccessService implements OXJSONAccess {
             boolean passHostHeaderFromClient = configurationManager.getProperty(
                 ConfigurationProperties.OX_ACCESS_PASS_HOST_HEADER_FROM_CLIENT,
                     ConfigurationProperties.OX_ACCESS_PASS_HOST_HEADER_FROM_CLIENT_DEFAULT, false);
+            String reloginErrorCodes = configurationManager.getProperty(ConfigurationProperties.OX_ACCESS_RELOGIN_ERROR_CODES_PROPERTY,
+                ConfigurationProperties.OX_ACCESS_RELOGIN_ERROR_CODES_DEFAULT, false);
 			_delegate.activate(journal.getLog(OXJSONAccess.class), accessUrl, maxConnections,
-					connectionTimeout, performStaleChecking, passHostHeaderFromClient);
+					connectionTimeout, performStaleChecking, passHostHeaderFromClient, reloginErrorCodes);
         } catch (USMInvalidConfigurationException e) {
 			throw new USMStartupException(OXJSONErrorCode.CONFIGURATION_ERROR,
 					"Could't read OX server access properties", e);
@@ -179,6 +179,10 @@ public class OXJSONAccessService implements OXJSONAccess {
         return _delegate.storeResource(path, action, session, params, json, data, contentType, jsonPartName, fileName);
     }
 
+    public JSONResult storeResourceFromStream(String path, String action, Session session, Map<String, String> params, JSONObject json, String contentType, long size, InputStreamProvider streamProvider) throws AuthenticationFailedException, OXCommunicationException {
+        return _delegate.storeResourceFromStream(path, action, session, params, json, contentType, size, streamProvider);
+    }
+
     public JSONResult storeResourceFromStream(String path, String action, Session session, Map<String, String> params, JSONObject json, String contentType, String jsonPartName, String fileName, long size, InputStreamProvider streamProvider) throws AuthenticationFailedException, OXCommunicationException {
         return _delegate.storeResourceFromStream(path, action, session, params, json, contentType, jsonPartName, fileName, size, streamProvider);
     }
