@@ -90,14 +90,17 @@ public class ResourceInputStreamImpl extends ResourceInputStream {
 
     private final long _contentLength;
 
+    private final String _description;
+
     private InputStream _inputStream;
 
     private long _lastActivity;
 
     private boolean _closed;
 
-    public ResourceInputStreamImpl(OXJSONAccessImpl oxjsonAccess, Session session, OXConnectionData connectionData, HttpMethod method, String contentType) throws IOException {
+    public ResourceInputStreamImpl(OXJSONAccessImpl oxjsonAccess, Session session, OXConnectionData connectionData, HttpMethod method, String contentType, String description) throws IOException {
         super();
+        _description = description;
         _oxJSONAccess = oxjsonAccess;
         _session = session;
         _method = method;
@@ -188,4 +191,9 @@ public class ResourceInputStreamImpl extends ResourceInputStream {
             _inputStream = _method.getResponseBodyAsStream();
         return _inputStream;
     }
+
+    @Override
+    public String toString() {
+        return "ResourceInputStream(" + _closed + ',' + _description + ')';
+    }
 }
