@@ -46,6 +46,7 @@
  *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  */
+
 package com.openexchange.usm.session.dataobject;
 
 import java.util.ArrayList;
@@ -55,11 +56,12 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
+import java.util.Set;
 import java.util.UUID;
-
 import com.openexchange.usm.api.session.DataObject;
 
 public class DataObjectSet implements Collection<DataObject> {
+
 	private final static String MISSING_ID_PREFIX = "DATAOBJECT_WITHOUT_ID_";
 
 	private final Map<String, DataObject> _idMap;
@@ -215,18 +217,23 @@ public class DataObjectSet implements Collection<DataObject> {
 		DataObject ob = remove(((DataObject) o).getID());
 		DataObject ob2 = null;
 
-		if (ob == null) {
-			for (Entry<String, DataObject> entry : _idMap.entrySet()) {
-				if (entry.getValue() == o)
-					ob = _idMap.remove(entry.getKey());
-			}
-			for (Entry<UUID, DataObject> entry : _uuidMap.entrySet()) {
-				if (entry.getValue() == o)
-					ob2 = _uuidMap.remove(entry.getKey());
-			}
-		} else {
-			ob2 = ob;
-		}
+        if (ob == null) {
+            for (Entry<String, DataObject> entry : _idMap.entrySet()) {
+                if (entry.getValue() == o) {
+                    ob = _idMap.remove(entry.getKey());
+                    break;
+                }
+            }
+            for (Entry<UUID, DataObject> entry : _uuidMap.entrySet()) {
+                if (entry.getValue() == o) {
+                    ob2 = _uuidMap.remove(entry.getKey());
+                    break;
+                }
+            }
+        } else {
+            ob2 = ob;
+        }
+
 
 		//		if (ob == null && _noIDCounter > 0) {
 		//			for (int i = 0; i < _noIDCounter; i++) {
@@ -279,16 +286,20 @@ public class DataObjectSet implements Collection<DataObject> {
 	public boolean isEqualTo(DataObject[] objects) {
         if(objects == null)
             return isEmpty();
-		if (size() != objects.length)
-			return false;
-		for (DataObject o : objects) {
-			if (o == null)
-				return false;
-			DataObject local = get(o.getID());
-			if (!o.equalsWithLastModified(local) || !DataObjectUtil.isEqual(o.getProtocolInformation(), local.getProtocolInformation())
-					|| !DataObjectUtil.isEqual(o.getUUID(), local.getUUID()))
-				return false;
-		}
-		return true;
-	}
+        if (size() != objects.length)
+            return false;
+        for (DataObject o : objects) {
+            if (o == null)
+                return false;
+            DataObject local = get(o.getID());
+            if (!o.equalsWithLastModified(local) || !DataObjectUtil.isEqual(o.getProtocolInformation(), local.getProtocolInformation())
+                    || !DataObjectUtil.isEqual(o.getUUID(), local.getUUID()))
+                return false;
+        }
+        return true;
+    }
+
+    public Set<String> getIDs() {
+        return _idMap.keySet();
+    }
 }
