@@ -54,8 +54,11 @@ import java.util.Collection;
 import java.util.List;
 import java.util.UUID;
 import com.openexchange.usm.api.contenttypes.ContentType;
+import com.openexchange.usm.api.contenttypes.DefaultContentTypes;
+import com.openexchange.usm.api.contenttypes.FolderConstants;
 import com.openexchange.usm.api.datatypes.DataType;
 import com.openexchange.usm.api.session.DataObject;
+import com.openexchange.usm.api.session.Folder;
 
 public class DataObjectUtil {
 
@@ -183,4 +186,21 @@ public class DataObjectUtil {
         Object f = o.getFieldContent(fieldName);
         return (f instanceof Number) ? ((Number) f).intValue() : 0;
     }
+
+    public static DataObject findMailFolder(String parentFolderId, String folderTitle, Iterable<DataObject> objects) {
+        if (parentFolderId != null && folderTitle != null) {
+            for (DataObject o : objects) {
+                if (o instanceof Folder) {
+                    Folder f = (Folder) o;
+                    try {
+                        if (DefaultContentTypes.MAIL_ID.equals(f.getElementsContentTypeID()) && parentFolderId.equals(o.getParentFolderID()) && folderTitle.equals(o.getFieldContent(FolderConstants.TITLE)))
+                            return o;
+                    } catch (Exception ignored) {
+                        // skip this object
+                    }
+                }
+            }
+        }
+        return null;
+    }
 }
