@@ -74,32 +74,26 @@ public class CachedData {
     }
 
     public long loadFromDB(long timestamp, Serializable[][] data) {
-        return internalStore(timestamp, data, 0L, 0L);
+        return internalStore(timestamp, data, 0L);
     }
 
-    public long store(long timestamp, Serializable[][] data, long timestampToKeep, long timestampToReplace) {
+    public long store(long timestamp, Serializable[][] data, long timestampToKeep) {
         if (_insertionIndex > 0) {
             // We have old entries, make sure the new timestamp is newer than the newest one already stored
             long lastTimestamp = _timestamps[_insertionIndex - 1];
             if (timestamp <= lastTimestamp)
                 timestamp = lastTimestamp + 1;
         }
-        return internalStore(timestamp, data, timestampToKeep, timestampToReplace);
+        return internalStore(timestamp, data, timestampToKeep);
     }
 
-    private synchronized long internalStore(long timestamp, Serializable[][] data, long timestampToKeep, long timestampToReplace) {
+    private synchronized long internalStore(long timestamp, Serializable[][] data, long timestampToKeep) {
         // Search for first(i.e. oldest) index new enough to keep
         int keepIndex = (timestampToKeep == 0L) ? 0 : Arrays.binarySearch(_timestamps, timestampToKeep);
         if (keepIndex < 0) // This should never be possible, just to be sure
             keepIndex = 1 + keepIndex;
         int size = _timestamps.length;
-        // search for the index of the timestamp to replace
-        int replaceIndex = (timestampToReplace == 0L) ? 0 : Arrays.binarySearch(_timestamps, timestampToReplace);
-        if (replaceIndex > 0) {
-            _timestamps[replaceIndex] = timestamp;
-            _lastAccess[replaceIndex] = System.currentTimeMillis();
-            _data[replaceIndex] = data;
-        } else if (keepIndex > 0) {
+        if (keepIndex > 0) {
             // We need to delete at least 1 entry per "normal" algorithm, therefore we always can store the new entry
             for (int i = keepIndex; i < size; i++) {
                 int j = i - keepIndex;
