@@ -58,7 +58,7 @@ public class DataObjectStorageSQLStatements {
 
 	public static final String SELECT_CACHED_DATA = "SELECT syncKey, element FROM USMDataStorage WHERE ";
 
-	public static final String SELECT_CACHED_DATA_ORDER_BY = " ORDER BY syncKey";
+	public static final String SELECT_CACHED_DATA_ORDER_BY = " ORDER BY syncKey DESC LIMIT ?";
 
 	public static final String UNIQUE_SESSION_IDENTIFIER = "cid = ? AND usmSessionId = ?";
 
