@@ -97,7 +97,6 @@ import com.openexchange.usm.api.session.SessionID;
 import com.openexchange.usm.api.session.SessionInitializer;
 import com.openexchange.usm.api.session.SyncResult;
 import com.openexchange.usm.api.session.UserID;
-import com.openexchange.usm.journal.Journal;
 import com.openexchange.usm.mapping.FolderIdMapping;
 import com.openexchange.usm.ox_json.JSONResult;
 import com.openexchange.usm.ox_json.JSONResultType;
@@ -192,6 +191,8 @@ public class SessionImpl implements Session, Serializable {
     private final ReentrantLock _oxLock = new ReentrantLock();
 
     private Map<String, String> _xHeaders = new HashMap<String, String>();
+    
+    private final Map<String,String> _mailFolderIdSeparators = new HashMap<String, String>();
 
     public SessionImpl(SessionManagerImpl sessionManager, String user, String password, String protocol, String device, SessionInitializer initializer) {
         _sessionManager = sessionManager;
@@ -228,6 +229,14 @@ public class SessionImpl implements Session, Serializable {
         _defaultInboxId = JSONToolkit.getString(configuration, "modules", "mail", "defaultFolder", "inbox");
         _defaultAddress = JSONToolkit.getString(configuration, "modules", "mail", "defaultaddress");
         _persistentData.initialize(_sessionInitializer, configuration);
+        JSONObject separators = JSONToolkit.getJSONObject(configuration, "modules", "mail", "separators");
+        if (separators != null) {
+            for (String key : JSONToolkit.keys(separators)) {
+                String separator = separators.optString(key);
+                if (separator != null)
+                    _mailFolderIdSeparators.put(key, separator);
+            }
+        }
     }
 
     private USMException generateInitializationException(String fieldName, Throwable cause) {
@@ -1228,16 +1237,12 @@ public class SessionImpl implements Session, Serializable {
             if (t == null)
                 t = o.getContentType();
             else if (!o.getContentType().getID().equals(t.getID())) {
-                throw new USMException(USMSessionManagementErrorCodes.ILLEGAL_OBJETCS_TO_BE_SAVED_IN_SYNC_STATE, "DataObjects of different ContentTypes");
-            }
-            if (o.getContentType().getCode() != DefaultContentTypes.RESOURCES_CODE 
-                && o.getContentType().getCode() != DefaultContentTypes.GROUPS_CODE
-                && !folderID.equals(o.getParentFolderID())) {
-                if (_sessionManager.getJournal().isDebugEnabled())
-                    _sessionManager.getJournal().debug("The DataObject with ID: " + o.getID() + " and UUID: " + o.getUUID() 
-                            + " is a child of " + o.getParentFolderID() + " instead of " +  folderID);
-                throw new USMException(USMSessionManagementErrorCodes.ILLEGAL_OBJETCS_TO_BE_SAVED_IN_SYNC_STATE, "DataObjects of different folders");
+                throw new USMException(
+                    USMSessionManagementErrorCodes.ILLEGAL_OBJETCS_TO_BE_SAVED_IN_SYNC_STATE,
+                    "DataObjects of different ContentTypes");
             }
+            if (o.getContentType().getCode() != DefaultContentTypes.RESOURCES_CODE && o.getContentType().getCode() != DefaultContentTypes.GROUPS_CODE)
+                o.setParentFolderID(folderID);
             set.add(o);
         }
         return set;
@@ -1432,6 +1437,10 @@ public class SessionImpl implements Session, Serializable {
     public SessionInitializer getSessionInitializer() {
         return _sessionInitializer;
     }
+    
+    public Map<String,String> getMailFolderIdSeparators() {
+        return _mailFolderIdSeparators;
+    }
 
     private void removeUnusedFoldersFromSyncStateStorage(Folder[] cachedFolders) throws DatabaseAccessException, USMSQLException {
         if (cachedFolders == null)
