@@ -530,7 +530,7 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
                 return;
         }
         _oxAjaxAccess.logout(session);
-        throw new USMAccessDeniedException(USMSessionManagementErrorCodes.USM_ACCESS_DISABLED, "USM access disabled for user " + session.getUserIdentifier() + " in context " + session.getContextId());
+        throw new USMAccessDeniedException(USMSessionManagementErrorCodes.USM_ACCESS_DISABLED, "USM access disabled for user " + session.getUserIdentifier() + '/' + session.getUser() + " in context " + session.getContextId());
     }
 
     private JSONObject getUSMModule(SessionImpl session, JSONObject configuration, String module) throws AuthenticationFailedException {
