@@ -159,7 +159,7 @@ public class SessionManagerService implements SessionManager {
         TempFileStorage.setManagedFileManagement(null);
     }
 
-	public boolean existsSessionInDB(String user, String protocol, String device) throws USMException {
-		return _delegate.existsSessionInDB(user, protocol, device);
+	public boolean existsSessionInDB(String user, String password, String protocol, String device) throws USMException {
+		return _delegate.existsSessionInDB(user, password, protocol, device);
 	}
 }
