@@ -227,21 +227,25 @@ public class SyncStateStorage {
         Log journal = getJournal();
 
         Serializable[][] serializedObjects = serializeObjects(objectSet);
-        byte[] data = compress(serializedObjects);
         long[] timestamps = getTimestamps(objectID);
         long newTS = timestamp;
         long oldTS = timestampToKeep;
         if (timestamps != null && timestamps.length > 0) {
             long newestTimestamp = getNewestTimestamp(timestamps);
-            byte[] newestData = getCompressedData(objectID, newestTimestamp);
-            if (Arrays.equals(data, newestData) || !hasStateChanged(newestTimestamp, newestData, objectSet, session)) {
+            Serializable[][] newestData = getCachedData(objectID, newestTimestamp);
+            if (!hasStateChanged(newestTimestamp, newestData, objectSet, session)) {
                 if (journal.isDebugEnabled())
                     journal.debug(_session + " Storing in DB cache not necessary, no changes for " + objectID + ", timestamp " + timestamp + "->" + newestTimestamp + ", keeping " + timestampToKeep);
                 return newestTimestamp;
             }
             newTS = Math.max(newestTimestamp + 1L, newTS);
+            int timestampLimit = _session.getSessionManager().getMaxSyncStatesInDB();
+            oldTS = updateLocalTimestamps(objectID, timestampLimit, timestampToKeep, newTS, timestamps);
+        } else {
+            storeLocalTimestamps(objectID, new long[] { newTS });
         }
 
+        byte[] data = compress(serializedObjects);
         // SyncStateStorageStatistics.collectCompressionStatistics(serializedObjects, data);
         boolean tooManyTimestamps = oldTS != timestampToKeep;
         String dbData = Toolkit.encodeBase64(data);
@@ -264,6 +268,7 @@ public class SyncStateStorage {
                 statement.setLong(NUMBER_OF_OBJECT_ID_FIELDS + 2, timestampToKeep);
             statement.executeUpdate();
             statement.close();
+            statement = null;
 
             int retries = 0;
             int executeUpdateAffectedRows = 0;
@@ -276,26 +281,20 @@ public class SyncStateStorage {
                 if (executeUpdateAffectedRows == 0) {
                     if (!_session.getSessionManager().getDatabaseAccess().supportsInsertIgnoreStatement())
                         throw new SQLException("Insert did not produce any results");
-                    else {
-                        retries++;
-                        newTS = newTS + 1L;
-                        if(getJournal().isDebugEnabled()) 
-                            getJournal().debug("Retry sync state insert for timestamp: " + newTS + " sessionId: " + _session.getSessionId() + " in context: " + _session.getContextId());
-                    }
+                    retries++;
+                    newTS = newTS + 1L;
+                    if (getJournal().isDebugEnabled())
+                        getJournal().debug("Retry sync state insert for timestamp: " + newTS + " sessionId: " + _session.getSessionId() + " in context: " + _session.getContextId());
                 }
+                Toolkit.close(statement);
+                statement = null;
             } while (retries < MAX_RETRIES_SYNC_STATE_INSERT_IN_DB && executeUpdateAffectedRows == 0);
-            
-            if(executeUpdateAffectedRows == 0) // throw exception if after 10 retries still no insert was possible
+
+            if (executeUpdateAffectedRows == 0) // throw exception if after 10 retries still no insert was possible
                 throw new SQLException("Insert did not produce any results");
 
-            //store the new timestamp in the local storage
-            if (timestamps != null && timestamps.length > 0) {
-                int timestampLimit = _session.getSessionManager().getMaxSyncStatesInDB();
-                oldTS = updateLocalTimestamps(objectID, timestampLimit, timestampToKeep, newTS, timestamps);
-            } else {
-                storeLocalTimestamps(objectID, new long[] { newTS });
-            }
-
+            // store the new timestamp in the local storage
+            _syncStateCache.put(_session.getCompleteSessionID(), objectID, newTS, serializedObjects);
         } catch (SQLException e) {
             throw new USMSQLException(
                 USMSessionManagementErrorCodes.DATA_STORAGE_ERROR_NUMBER1,
@@ -309,22 +308,17 @@ public class SyncStateStorage {
         return newTS;
     }
 
-    private static boolean hasStateChanged(long newestTimestamp, byte[] compressedData, DataObjectSet objects, SessionImpl session) {
-        try {
-            Serializable[][] serializedData = decompress(compressedData);
-            int len1 = (serializedData == null) ? 0 : serializedData.length;
-            int len2 = (objects == null) ? 0 : objects.size();
-            if (len1 != len2)
-                return true;
-            if (len1 == 0)
-                return false;
-
-            ContentType contentType = objects.iterator().next().getContentType();
-            DataObject[] cachedObjects = deserializeObjects(serializedData, newestTimestamp, contentType, session);
-            return !objects.isEqualTo(cachedObjects);
-        } catch (DeserializationFailedException e) {
+    private static boolean hasStateChanged(long newestTimestamp, Serializable[][] serializedData, DataObjectSet objects, SessionImpl session) {
+        int len1 = (serializedData == null) ? 0 : serializedData.length;
+        int len2 = (objects == null) ? 0 : objects.size();
+        if (len1 != len2)
             return true;
-        }
+        if (len1 == 0)
+            return false;
+
+        ContentType contentType = objects.iterator().next().getContentType();
+        DataObject[] cachedObjects = deserializeObjects(serializedData, newestTimestamp, contentType, session);
+        return !objects.isEqualTo(cachedObjects);
     }
 
     private static DataObject[] deserializeObjects(Serializable[][] values, long timestamp, ContentType contentType, SessionImpl session) {
@@ -351,17 +345,11 @@ public class SyncStateStorage {
     }
 
     public Serializable[][] get(String objectID, long timestamp) throws DatabaseAccessException, USMSQLException {
-        byte[] data = getCompressedData(objectID, timestamp);
-        try {
-            return (data == null) ? null : decompress(data);
-        } catch (DeserializationFailedException e) {
-            _session.logDeserializationError(objectID, timestamp, e);
-            return null;
-        }
+        return getCachedData(objectID, timestamp);
     }
 
-    private byte[] getCompressedData(String objectID, long timestamp) throws DatabaseAccessException, USMSQLException {
-        byte[] data = _syncStateCache.get(getSessionID(), objectID, timestamp);
+    private Serializable[][] getCachedData(String objectID, long timestamp) throws DatabaseAccessException, USMSQLException {
+        Serializable[][] data = _syncStateCache.get(getSessionID(), objectID, timestamp);
         if (data != null)
             return data;
         readSyncStatesFromDB(objectID);
@@ -545,6 +533,7 @@ public class SyncStateStorage {
             con = _session.getReadOnlyDBConnection();
             statement = con.prepareStatement(DataObjectStorageSQLStatements.SELECT_CACHED_DATA + DataObjectStorageSQLStatements.UNIQUE_OBJECT_IDENTIFIER + DataObjectStorageSQLStatements.SELECT_CACHED_DATA_ORDER_BY);
             addObjectIdentifierToStatement(statement, objectID);
+            statement.setInt(NUMBER_OF_SESSION_ID_FIELDS + 2, _session.getSessionManager().getMaxSyncStatesInDB());
             ResultSet result = statement.executeQuery();
             while (result.next()) {
                 long timestamp = result.getLong(1);
@@ -563,8 +552,17 @@ public class SyncStateStorage {
         _syncStateCache.removeSyncStates(getSessionID(), objectID);
         int i = 0;
         for (CachedDBEntry entry : dbList) {
-            timestamps[i] = entry.getTimestamp();
-            _syncStateCache.put(getSessionID(), objectID, entry.getTimestamp(), Toolkit.decodeBase64(entry.getData()));
+            try {
+                _syncStateCache.put(getSessionID(), objectID, entry.getTimestamp(), decompress(Toolkit.decodeBase64(entry.getData())));
+                timestamps[i++] = entry.getTimestamp();
+            } catch (DeserializationFailedException e) {
+                _session.logDeserializationError(objectID, entry.getTimestamp(), e);
+            }
+        }
+        if (timestamps.length != i) { // In case a DeserializationFailedException occurred
+            long[] deserializedTimestamps = new long[i];
+            System.arraycopy(timestamps, 0, deserializedTimestamps, 0, i);
+            timestamps = deserializedTimestamps;
         }
         storeLocalTimestamps(objectID, timestamps);
         _session.getSessionManager().syncStatesLoadedFromDatabase(dbList.size());
