@@ -76,9 +76,6 @@ public class USMSessionInformation extends StandardMBean implements USMSessionIn
             "WaitForChangesEmailMinPullDelay",
             "Minimum time in ms. before an internal pull is performed if a client waits on email folder changes. A value < 0 disables internal email pulling completely");
         DESCRIPTIONS.put("MaxSyncStatesInDB", "Maximum number of SyncStates kept in database for any folder of a session");
-        DESCRIPTIONS.put(
-            "KeepLastSentSyncStateInDB",
-            "If set, the last SyncState used by a client is always kept in the database, if not, only the N newest ones are kept");
         DESCRIPTIONS.put("ActiveSessionCount", "Number of currently active (i.e. stored in local memory) USM sessions");
         DESCRIPTIONS.put("listActiveSessions", "Lists all currently active USM sessions");
         DESCRIPTIONS.put(
@@ -175,14 +172,6 @@ public class USMSessionInformation extends StandardMBean implements USMSessionIn
         return _sessionManager.getSessionStorage().getSessionCount();
     }
 
-    public boolean getKeepLastSentSyncStateInDB() {
-        return _sessionManager.isKeepLastSentSyncStateInDB();
-    }
-
-    public void setKeepLastSentSyncStateInDB(boolean set) {
-        _sessionManager.setKeepLastSentSyncStateInDB(set);
-    }
-
     public int getMaxSyncStatesInDB() {
         return _sessionManager.getMaxSyncStatesInDB();
     }
