@@ -113,8 +113,9 @@ public abstract class BaseContentSyncer {
                 return new DataObjectSet(_oxDataCache.getData());
             }
         }
-        DataObjectSet serverDataObjects = storage.getCurrentServerData();
-        if (allowCache) {
+        DataObjectSet serverDataObjects = new DataObjectSet();
+        boolean isComplete = storage.getCurrentServerData(serverDataObjects);
+        if (allowCache && isComplete) {
             _oxDataCache = _sessionManager.getOXDataCache().storeCachedData(storage.getCacheID(), serverDataObjects.toArray());
         } else {
             _oxDataCache = null;
