@@ -78,7 +78,7 @@ public interface ContentSyncerStorage {
      *            marked as "in sync" (for waitForChanges)
      * @return
      */
-    long storeServerData(long timestamp, DataObjectSet data, boolean updatesPending) throws DatabaseAccessException, USMSQLException;
+    long storeServerData(long timestamp, DataObjectSet data, boolean updatesPending) throws USMException;
 
     /**
      * @return {@link OXDataCacheID} for the OX server storage (a specific folder or the folder hierarchy for a session)
