@@ -67,10 +67,9 @@ import com.openexchange.usm.session.dataobject.DataObjectSet;
 import com.openexchange.usm.session.dataobject.DataObjectUtil;
 import com.openexchange.usm.session.dataobject.FolderHierarchyComparator;
 import com.openexchange.usm.session.impl.SessionManagerImpl;
+import com.openexchange.usm.session.impl.USMSessionManagementErrorCodes;
 
 public class ContentSyncerSupport {
-	private static final String TITLE = "title";
-
     private static final String ID = "id";
 
 	private static final boolean READ_SERVER_CHANGES_ON_CREATION = true;
@@ -148,7 +147,7 @@ public class ContentSyncerSupport {
 				serverChanges);
 	}
 
-    private static String getLatestMappedID(String originalID, Map<String, String> folderIdMapping) {
+    protected static String getLatestMappedID(String originalID, Map<String, String> folderIdMapping) {
         String newMappedID = folderIdMapping.get(originalID);
         if (!folderIdMapping.containsKey(newMappedID))
             return newMappedID;
@@ -190,45 +189,44 @@ public class ContentSyncerSupport {
 					    serverObject.commitChanges();
 					}
 				}
-				if (isFolder && serverObject != null && change.isFieldModified(change.getFieldIndex(ID))) {
+				if (isFolder && serverObject != null && change.isFieldModified(ID)) {
 					//this means that we have renamed/moved a mail folder and the id is changed and we have to remap all cached data to the new id
-				    String originalID = change.getOriginalID();
-				    String newID = serverObject.getID();
+                    Session session = serverObject.getSession();
+                    String separator = getMailFolderIdSeparator(session, serverObject);
+                    String originalID = change.getOriginalID();
+                    String newID = serverObject.getID();
+                    String originalIDPrefix = originalID + separator;
+                    String newIDPrefix = newID + separator;
 				    
 				    String newOriginalID = getLatestMappedID(originalID, folderIdMapping); //if the parent folder has also been renamed in the same update and we already have a new id mapped
-				    if(newOriginalID != null) 
-				        originalID = newOriginalID;
-				    folderIdMapping.put(originalID, newID); //old to new
-				    
-				   
-					Session session = serverObject.getSession();
-					session.remapCachedData(session.getShortFolderID(originalID), session
-							.getShortFolderID(newID));
-					for (DataObject childFolder : serverObjects) {
-					    String childFolderID = childFolder.getID();
-						if (childFolderID.startsWith(originalID + "/")) {
-                            // folder is child (or grand-child) of modified folder
-                            // beginIndex is position where sub-path of folder (child) begins (after /)
-                            int beginIndex = originalID.length() + 1;
-                            String childSubPath = childFolderID.substring(beginIndex);
-							String newParentFolderID = newID;
-							int childParentDelimiterIndex = childSubPath.lastIndexOf('/');
-							if(childParentDelimiterIndex >= 0) {
-	                            // folder is grand-child of modified folder, add intermediate folder structure
-							    newParentFolderID += "/" + childSubPath.substring(0, childParentDelimiterIndex);
-							}
-							String newChildID = newID + "/" + childSubPath;
-							folderIdMapping.put(childFolderID, newChildID); //old to new
-							childFolder.setParentFolderID(newParentFolderID);
-							childFolder.setID(newChildID);
-							session = childFolder.getSession();
-							session.remapCachedData(session.getShortFolderID(childFolderID), session
-									.getShortFolderID(newChildID));
-							childFolder.commitChanges();
-						}
-					}
+                    if (newOriginalID != null)
+                        originalID = newOriginalID;
+                    folderIdMapping.put(originalID, newID); // old to new
+
+                    session.remapCachedData(session.getShortFolderID(originalID), session.getShortFolderID(newID));
+                    for (DataObject childFolder : serverObjects) {
+                        String childFolderID = childFolder.getID();
+                        boolean modified = false;
+                        if (childFolderID.startsWith(originalIDPrefix)) {
+                            String newChildFolderID = newIDPrefix + childFolderID.substring(originalIDPrefix.length());
+                            folderIdMapping.put(childFolderID, newChildFolderID); // old to new
+                            childFolder.setID(newChildFolderID);
+                            session.remapCachedData(session.getShortFolderID(childFolderID), session.getShortFolderID(newChildFolderID));
+                            modified = true;
+                        }
+                        String parentFolderID = childFolder.getParentFolderID();
+                        if (parentFolderID.equals(originalID)) {
+                            childFolder.setParentFolderID(newID);
+                            modified = true;
+                        } else if (parentFolderID.startsWith(originalIDPrefix)) {
+                            String newParentFolderID = newIDPrefix + parentFolderID.substring(originalIDPrefix.length());
+                            childFolder.setParentFolderID(newParentFolderID);
+                            modified = true;
+                        }
+                        if (modified)
+                            childFolder.commitChanges();
+                    }
 				}
-				
 			}
 		});
 		// perform deletions of already existing objects
@@ -255,6 +253,8 @@ public class ContentSyncerSupport {
 					creation.setParentFolder(f);
 				ContentType contentType = creation.getContentType();
 				contentType.getTransferHandler().writeNewDataObject(creation);
+				if(serverObjects.contains(creation.getID()))
+				    throw new USMException(USMSessionManagementErrorCodes.DUPLICATE_FOLDER_CREATION, "Folder already exists");
 				DataObject creationCopy = creation.createCopy(true);
 				if (READ_SERVER_CHANGES_ON_CREATION) {
 					readServerChanges(sessionManager, serverChanges, creation, f, contentType);
@@ -271,7 +271,22 @@ public class ContentSyncerSupport {
 		});
 	}
 
-	private static void readServerChanges(final SessionManagerImpl sessionManager,
+    protected static String getMailFolderIdSeparator(Session session, DataObject serverObject) {
+        String separator = "/"; // default ?
+        String folderId = serverObject.getID();
+        if (folderId.startsWith("default")) { // is a mail folder
+            String part = folderId.substring("default".length());
+            // search longest account id that matches
+            for (Map.Entry<String, String> entry : session.getMailFolderIdSeparators().entrySet()) {
+                String accountId = entry.getKey();
+                if (accountId.length() >= separator.length() && part.startsWith(accountId))
+                    separator = entry.getValue();
+            }
+        }
+        return separator;
+    }
+
+    protected static void readServerChanges(final SessionManagerImpl sessionManager,
 			final List<DataObject> serverChanges, DataObject creation, Folder f, ContentType contentType) {
 		if (mayHaveRightsToReadElements(f)) {
 			try {
