@@ -50,14 +50,11 @@
 package com.openexchange.usm.session.sync;
 
 import java.util.BitSet;
-import java.util.UUID;
 import com.openexchange.usm.api.contenttypes.ContentType;
 import com.openexchange.usm.api.contenttypes.FolderConstants;
 import com.openexchange.usm.api.contenttypes.FolderContentType;
 import com.openexchange.usm.api.contenttypes.FolderContentTypeTransferHandler;
-import com.openexchange.usm.api.database.DatabaseAccessException;
 import com.openexchange.usm.api.exceptions.USMException;
-import com.openexchange.usm.api.exceptions.USMSQLException;
 import com.openexchange.usm.api.session.DataObject;
 import com.openexchange.usm.api.session.DataObjectFilter;
 import com.openexchange.usm.api.session.Folder;
@@ -75,6 +72,8 @@ public class FolderHierarchyStorage implements ContentSyncerStorage {
     private final String[] _rootFolders;
 
     private final long _oldTimestamp;
+    
+    private final long _syncStartTimestamp;
 
     private final OXDataCacheID _cacheID;
 
@@ -84,6 +83,7 @@ public class FolderHierarchyStorage implements ContentSyncerStorage {
         _storeResult = storeResult;
         _oldTimestamp = (filter != null && filter.getOriginalSyncID() != 0L) ? filter.getOriginalSyncID() : oldTimestamp;
         _rootFolders = rootFolders;
+        _syncStartTimestamp = System.currentTimeMillis();
         _cacheID = session.getFolderHierarchyCacheID();
     }
 
@@ -115,8 +115,8 @@ public class FolderHierarchyStorage implements ContentSyncerStorage {
         return false;
     }
 
-    public long storeServerData(long timestamp, DataObjectSet data, boolean updatesPending) throws DatabaseAccessException, USMSQLException {
-        return _storeResult ? _session.storeCachedFolders(_oldTimestamp, timestamp, data, updatesPending) : 0L;
+    public long storeServerData(long timestamp, DataObjectSet data, boolean updatesPending) throws USMException {
+        return _storeResult ? _session.storeCachedFolders(_oldTimestamp, timestamp, data, updatesPending, _syncStartTimestamp) : 0L;
     }
 
     public OXDataCacheID getCacheID() {
@@ -159,12 +159,14 @@ public class FolderHierarchyStorage implements ContentSyncerStorage {
         Object v = serverObject.getFieldContent(FolderConstants.STANDARD_FOLDER_TYPE);
         if (!(v instanceof Number) || ((Number) v).intValue() == 0)
             return null;
-        for (DataObject i : clientDataObjects) {
-            if (v.equals(i.getFieldContent(FolderConstants.STANDARD_FOLDER_TYPE)))
+        //FIXME: Issues with Unified Mail - for more info in relevant e-mail message
+        /*for (DataObject i : clientDataObjects) {
+            if (v.equals(i.getFieldContent(FolderConstants.STANDARD_FOLDER_TYPE))) {
                 _session.getSessionManager().getJournal().warn(
                     _session + " Standard folder (type " + v + ") changed OX id: '" + i.getID() + "' -> '" + serverObject.getID() + '\'');
-            return i;
-        }
+              return i;
+            }
+        }*/
         return null;
     }
 }
