@@ -288,29 +288,27 @@ public class IncrementalContentSyncer extends BaseContentSyncer {
 				"Too many repeated conflicts on incremental sync");
 	}
 
-	private boolean isDuplicateCreation(DataObjectSet serverCreationSet, DataObject f,
-			List<DataObject> serverCreations, DataObjectSet cachedDataobjects) {
-		if (f.getChangeState() == ChangeState.CREATED && f.getUUID() != null) {
-			
-			if (!cachedDataobjects.contains(f.getUUID()))
-				return false; //not a duplicate creation,  attempt to create folder which already exist on server
-			DataObject sc = serverCreationSet.get(f.getUUID());
-			if (DefaultContentTypes.FOLDER_ID.equals(f.getContentType().getID())
-					&& DefaultContentTypes.MAIL_ID.equals(((Folder) f).getElementsContentTypeID())) {
-				Object title = f.getFieldContent("title");
-				String parentFolderID = f.getParentFolderID();
-				String id = (parentFolderID == null ? "" : parentFolderID) + "/" + (title == null ? "" : title);
-				sc = serverCreationSet.get(id);
-			}
-			if (sc != null) {
-				// If a creation with a UUID already exists in the server, nothing is to do, since the creation was already performed in a previous call, but the result did not reach the client
-				f.setID(sc.getID());
-				serverCreations.remove(sc);
-				return true;
-			}
-		}
-		return false;
-	}
+    private static boolean isDuplicateCreation(DataObjectSet serverCreationSet, DataObject f, List<DataObject> serverCreations, DataObjectSet cachedDataobjects) {
+        if (f.getChangeState() == ChangeState.CREATED && f.getUUID() != null) {
+            DataObject sc = serverCreationSet.get(f.getUUID());
+            if (sc == null && DefaultContentTypes.FOLDER_ID.equals(f.getContentType().getID()) && DefaultContentTypes.MAIL_ID.equals(((Folder) f).getElementsContentTypeID())) {
+                Object t = f.getFieldContent("title");
+                String title = (t instanceof String) ? (String)t : null;
+                String parentFolderID = f.getParentFolderID();
+                if(DataObjectUtil.findMailFolder(parentFolderID, title, cachedDataobjects) != null)
+                    return false; // not a duplicate creation, attempt to create folder which already exist on server
+                sc = DataObjectUtil.findMailFolder(parentFolderID, title, serverCreationSet);
+            }
+            if (sc != null) {
+                // If a creation with a UUID already exists in the server, nothing is to do, since the creation was already performed in a
+                // previous call, but the result did not reach the client
+                f.setID(sc.getID());
+                serverCreations.remove(sc);
+                return true;
+            }
+        }
+        return false;
+    }
 
 	private void checkRequestedChanges(DataObjectSet cachedDataObjects, DataObject f) throws InternalUSMException {
 		switch (f.getChangeState()) {
