@@ -52,8 +52,9 @@ package com.openexchange.usm.session.sync;
 import java.text.SimpleDateFormat;
 import java.util.Date;
 import java.util.concurrent.ConcurrentHashMap;
+import java.util.concurrent.CountDownLatch;
+import java.util.concurrent.TimeUnit;
 import com.openexchange.usm.api.session.SessionID;
-import com.openexchange.usm.session.impl.SessionImpl;
 
 /**
  * {@link SynchronizationLock}
@@ -70,8 +71,8 @@ public final class SynchronizationLock {
 
         private final String _id;
 
-        public LockKey(SessionImpl session, String id) {
-            _sessionID = session.getCompleteSessionID().getSessionID();
+        public LockKey(SessionID sessionID, String id) {
+            _sessionID = sessionID;
             _id = id;
         }
 
@@ -91,7 +92,38 @@ public final class SynchronizationLock {
         }
     }
 
-    private static final ConcurrentHashMap<LockKey, String> _lockedKeys = new ConcurrentHashMap<LockKey, String>(16, 0.75f, 1);
+    private static class LockValue {
+
+        private final String _acquirer;
+
+        private final CountDownLatch _countdownLatch;
+
+        public LockValue(String acquirer) {
+            _acquirer = acquirer;
+            _countdownLatch = new CountDownLatch(1);
+        }
+
+        public String getAcquirer() {
+            return _acquirer;
+        }
+
+        public CountDownLatch getCountdownLatch() {
+            return _countdownLatch;
+        }
+    }
+
+    private static long _lockTimeout;
+
+    private static final ConcurrentHashMap<LockKey, LockValue> _lockedKeys = new ConcurrentHashMap<LockKey, LockValue>(16, 0.75f, 1);
+
+    /**
+     * Configures the timeout to use for acquiring locks on specific session locks.
+     * 
+     * @param timeout timeout in milliseconds: The lock() method will wait for upto this time when trying to gain exclusive access to the specified lock
+     */
+    public static void setLockTimeout(long timeout) {
+        _lockTimeout = timeout;
+    }
 
     /**
      * Tries to acquire a lock for a given ID in a given session. Locks are acquired per session per ID. For different sessions and/or IDs a
@@ -105,8 +137,26 @@ public final class SynchronizationLock {
      * @return null if lock was acquired successfully, String stored as acquirer by the code that currently holds the lock if the lock is
      *         currently not available
      */
-    public static String lock(SessionImpl session, String id, String acquirer) {
-        return _lockedKeys.putIfAbsent(new LockKey(session, id), buildAcquirerWithDateTime(acquirer));
+    public static String lock(SessionID sessionID, String id, String acquirer) {
+        LockKey key = new LockKey(sessionID, id);
+        LockValue value = new LockValue(buildAcquirerWithDateTime(acquirer));
+        LockValue oldValue = _lockedKeys.putIfAbsent(key, value);
+        if (oldValue == null)
+            return null;
+        long now = System.currentTimeMillis();
+        long limit = now + _lockTimeout;
+        for (; now < limit; now = System.currentTimeMillis()) {
+            try {
+                if (oldValue.getCountdownLatch().await(limit - now, TimeUnit.MILLISECONDS)) {
+                    oldValue = _lockedKeys.putIfAbsent(key, value);
+                    if (oldValue == null)
+                        return null;
+                }
+            } catch (InterruptedException e) {
+                break;
+            }
+        }
+        return oldValue.getAcquirer();
     }
 
     private static String buildAcquirerWithDateTime(String acquirer) {
@@ -122,7 +172,9 @@ public final class SynchronizationLock {
      * @param session
      * @param id
      */
-    public static void unlock(SessionImpl session, String id) {
-        _lockedKeys.remove(new LockKey(session, id));
+    public static void unlock(SessionID sessionID, String id) {
+        LockValue lock = _lockedKeys.remove(new LockKey(sessionID, id)); // Remove lock from table
+        if (lock != null)
+            lock.getCountdownLatch().countDown(); // Notify any threads that were waiting on lock
     }
 }
