@@ -49,7 +49,9 @@
 
 package com.openexchange.usm.util;
 
-import java.sql.*;
+import java.sql.PreparedStatement;
+import java.sql.ResultSet;
+import java.sql.SQLException;
 import com.openexchange.usm.api.database.EncapsulatedConnection;
 
 public class SQLToolkit {
